	SUBROUTINE NEWPHK (TIMARG)
C
C --- NEWPHK                          
C --- CALLED BY DIFFUN                
C --- CALLS NWSDST
C --- NO FILE I/O                     
C
C	CALCULATES PHOTOLYSIS RATES FOR CURRENT TIME FOR VARYHV=T.
C
C	TIMARG = MINUTES AFTER MIDNIGHT
C		(IF NEGATIVE, CALLS NEWSOL TO INPUT NON-DEFAULT SOLAR
C		SDIST PARMS)
C	SINLD = SIN (LATITUDE) * SIN (DECLINATION)
C	COSLD = COS (LATITUDE) * COS (DECLINATION)
C
	REAL TIMARG
C
	INCLUDE 'MAINSPC.FOR'
C
	PARAMETER (HR24=1440.0,HR12=720.0,RADDEG=4.363323E-3)
C
C
C	SET ALL TO ZERO AND RETURN IF CHEMISTRY TURNED OFF
C
	IF (NOCHEM) THEN
		DO 7001 I=1,NPHOTK
 7001		COEF(IPHRK(I))=0.0
		RETURN
	ENDIF
C
C	SEE IF CALL IS FOR INPUT FOR NEW SOLAR SDIST PARMS ONLY
C
	IF (TIMARG.LT.0.0) THEN
		CALL NEWSOL
		RETURN
	ENDIF
C
C
 2000	TX=TIMARG+TSTART
	IF (TX.GE.HR24) TX=TX-HR24*AINT(TX/HR24)
	IF (TX.GT.HR12) TX=HR24-TX
        IF (TX.EQ.TXLAST) GOTO 900
 	TXLAST=TX
	IF (TX.LE.TDAWN) THEN
C		PHOTKS AT NIGHT:  CALCULATED FOR COSZ = CZMIN
		COSZ=CZMIN
	ELSE
		COSZ=(SINLD-COS(RADDEG*TX)*COSLD)
		IF (COSZ.LT.CZMIN) COSZ=CZMIN
	ENDIF
C
	IF (ICOSZ.NE.0) COEF(ICOSZ)=COSZ
C
        IF (COSZ.EQ.CZMIN) THEN
		IF (NODARK) THEN
C
C			CALCS PHOTKS FOR "DARK" COSZ (CZMIN)
C
			IF (SUN) THEN
	                        CALL NWSDST  
			ELSE
				CALL PZCALC
			ENDIF
 			DO 2004 I=1,NPHOTK
 2004			DPHOTK(I)=COEF(IPHRK(I))
			NODARK=.FALSE.
		ELSE
			DO 2006 I=1,NPHOTK
	 		COEF(IPHRK(I))=DPHOTK(I)
 2006			CONTINUE	
		ENDIF
C
	ELSE
C
C		CALC PHOTKS FOR COSZ
C
		IF (SUN) THEN
	                CALL NWSDST	!CALC DEFAULT SOLAR SDIST AND PHOTKS
		ELSE
			CALL PZCALC
		ENDIF
	ENDIF
C
  900	RETURN
        END
C
C -----------------------------------------------------------------------
        SUBROUTINE NWSDST 
C
C ---- CALLED BY NEWPHK
C ---- CALLS NOTHING
C ---- NO FILE I/O
C   
C	SUBROUTINE TO CALC SOLAR SPECTAL DISTRIBUTION
C
	INCLUDE 'MAINSPC.FOR'
C
C     PARAMETERS USED WERE ADJUSTED TO FIT ACTINIC FLUXES AS FUNCTION OF
C     ZENITH ANGLE CALCULATED BY PETERSON (EPA-600/4-76-025) USING
C     'BEST ESTIMATE' SURFACE ALBEDOS (SEE TABLE 4, P. 21 AND APPENDIX B
C     ,P.51).   CALCULATED FLUXES WERE FOR O3STRT=0.295  CM-ATM, AND FLU
C     XES FOR DIFFERENT O3STRT CAN'T BE CALCULATED IN THIS VERSION.  FLUXES
C     FOR WL=290-700 CALCULATED EXPLICITLY.  SDIST DEFINED FOR 290-1000,
C     WITH 700-1000 ASSUMED TO BE CONSTANT.
C
C	ADDED 10/88:  SDIST FOR Z > 78 DEGREES CALCULATED USING
C		SDIST(COSZ)=SDIST(COS78) * (COSZ/COS78)**FPARM
C	SD78 ARRAY ADDED TO HOLD SDIST(COS78).  NOTE COS78=0.207912
C
	PARAMETER (NSOLSD=48,NSOLS1=NSOLSD+1)
C	NSOLWL=27.  NSOLWL SPECIFIED IN MAINSPC.FTN
C
	REAL SSDIST(NSOLWL),APARM(NSOLSD),BPARM(NSOLSD),EPARM(NSOLSD),
     &	 FPARM(NSOLSD)
	LOGICAL NOSD78
        REAL COSZ2
        REAL SOLWL(NSOLS1),SD78(NSOLS1)
C
C	FOLLOWING ARE WL'S FOR WHICH PARMS ARE GIVEN
C
	DATA SOLWL /0.295,   0.300,   0.305,   0.310,   0.315,
     &	   0.320,   0.325,   0.330,   0.335,   0.340,   0.345,
     &	   0.350,   0.355,   0.360,   0.365,   0.370,   0.375,
     &     0.380,   0.385,   0.390,   0.395,   0.400,   0.405,
     &     0.410,   0.415,   0.420,   0.430,   0.440,   0.450,
     &	   0.460,   0.470,   0.480,   0.490,   0.500,   0.510,
     &     0.520,   0.530,   0.540,   0.550,   0.560,   0.570,
     &     0.580,   0.600,   0.620,   0.640,   0.660,   0.680,
     &	   0.700,   1.000/
C
C	FOLLOWING ARE WAVELENGTHS FOR WHICH ABS*QY DATA ARE
C	STORED.  SOME (HIGHER) WAVELENGTH INTERVALS LUMPED
C	TOGETHER, AND SDIST SUMMED FOR THESE.
C	**** THIS ARRAY IS LOCAL TO MODL, BUT MUST BE AS SHOWN BELOW:
C
C	DATA SOLWL /	 0.295,   0.300,    0.305,    0.310,    0.315,
C     &		0.320,   0.325,   0.330,    0.335,    0.340,    0.345,        
C     &		0.350,            0.360,              0.370,
C     &		0.380,            0.390,              0.400,
C     &		0.410,            0.420,    0.430,    0.440,    0.450,
C     &		0.460,   0.470,   0.480,    0.490,    0.500,
C     &	                 1.000,  27*0.0/
C
	DATA APARM /
     &	   4.71E16, 4.98E16, 6.13E16, 7.33E16, 7.54E16, 8.06E16,
     &     1.04E17, 1.03E17, 9.68E16, 1.00E17, 9.75E16, 1.08E17,
     &     9.69E16, 1.05E17, 1.26E17, 1.12E17, 1.22E17, 9.96E16,
     &     1.08E17, 1.10E17, 1.31E17, 1.56E17, 1.73E17, 1.81E17,
     &     1.81E17, 3.50E17, 3.54E17, 4.06E17, 4.60E17, 4.66E17,
     &     4.72E17, 4.64E17, 4.62E17, 4.80E17, 4.69E17, 4.75E17,
     &     4.75E17, 4.66E17, 4.71E17, 4.75E17, 4.85E17, 9.80E17,
     &     9.94E17, 9.83E17, 1.00E18, 1.02E18, 1.00E18, 1.51E19/
C
	DATA BPARM /
     &     5.253,   3.037,   1.981,   1.354,   1.057,   0.896,
     &     0.791,   0.722,   0.671,   0.634,   0.605,   0.578,
     &     0.556,   0.533,   0.513,   0.495,   0.476,   0.458,
     &     0.443,   0.429,   0.414,   0.409,   0.394,   0.384,
     &     0.372,   0.357,   0.339,   0.326,   0.324,   0.312,
     &     0.301,   0.292,   0.285,   0.290,   0.285,   0.282,
     &     0.281,   0.278,   0.280,   0.279,   0.280,   0.273,
     &     0.273,   0.258,   0.251,   0.245,   0.236,   0.236/
C
	DATA EPARM /
     &     0.046,   0.044,   0.043,   0.035,   0.034,   0.034,
     &     0.032,   0.030,   0.027,   0.025,   0.023,   0.020,
     &     0.018,   0.016,   0.015,   0.013,   0.011,   0.010,
     &     0.009,   0.008,   0.007,   0.007,   0.005,   0.005,
     &     0.004,   0.003,   0.002,   0.002,   0.002,   0.001,
     &     0.001,   0.000,   0.000,   0.000,   0.000,   0.000,
     &     0.000,   0.000,   0.000,   0.000,   0.000,   0.000,
     &     0.000,   0.000,   0.000,   0.000,   0.000,   0.000/
C
	DATA FPARM /
     &     2.0,     2.0,     2.0,     2.0,     2.0,     1.8,
     &     1.6,     1.5,     1.5,     1.5,     1.5,     1.5,
     &     1.5,     1.5,     1.5,     1.5,     1.5,     1.5,
     &     1.5,     1.5,     1.5,     1.5,     1.5,     1.5,
     &     1.5,     1.5,     1.5,     1.5,     1.5,     1.5,
     &     1.5,     1.5,     1.5,     1.5,     1.5,     1.5,
     &     1.5,     1.5,     1.5,     1.5,     1.5,     1.5,
     &     1.5,     1.5,     1.5,     1.5,     1.5,     1.5/
C
	DATA NOSD78/.TRUE./CZ78/0.207812/
C
C	THE FOLLOWING FUNCTION IS USED TO DEFINE SPECTRAL DIST
C
	SOLSD(AI,BI,EI)=AI*EXP(-BI*SQRT((1.0+EI)/(COSZ2+EI)))
C ----------------------------------------------------------------------
C
C** ADDED 5/89
C	IF (COSZ.LE.CZMIN) THEN
C		DO 70 I=1,NPHOTK
C   70		COEF(IPHRK(I))=0.0
C		RETURN
C	ENDIF
C*** END ADDITION
	IF (COSZ.LT.CZ78) THEN
		IF (NOSD78) THEN
		        COSZ2=CZ78**2
			DO 80 I=1,NSOLSD
   80			SD78(I)=SOLSD(APARM(I),BPARM(I),EPARM(I))
			NOSD78=.FALSE.
		ENDIF
C
		COSZR=COSZ/CZ78
		DO 82 I=1,11
   82		SSDIST(I)=SD78(I)*(COSZR**FPARM(I))
		I1=11
		DO 84 J=12,18
		I=I1+1
		I1=I+1
   84		SSDIST(J)=(SD78(I)*(COSZR**FPARM(I)))+
     &		 (SD78(I1)*(COSZR**FPARM(I1)))
		DO 86 I=26,33
   86		SSDIST(I-7)=SD78(I)*(COSZR**FPARM(I))
		RKI=0.0
		DO 88 I=34,48
   88		RKI=RKI+(SD78(I)*(COSZR**FPARM(I)))
		SSDIST(27)=RKI
C
	ELSE
C
	        COSZ2=COSZ**2
		DO 100 I=1,11
  100		SSDIST(I)=SOLSD(APARM(I),BPARM(I),EPARM(I))
		I1=11
		DO 102 J=12,18
		I=I1+1
		I1=I+1
  102		SSDIST(J)=SOLSD(APARM(I),BPARM(I),EPARM(I))
     &		 +SOLSD(APARM(I1),BPARM(I1),EPARM(I1))
		DO 104 I=26,33
  104		SSDIST(I-7)=SOLSD(APARM(I),BPARM(I),EPARM(I))
		RKI=0.0
		DO 106 I=34,48
  106		RKI=RKI+SOLSD(APARM(I),BPARM(I),EPARM(I))
		SSDIST(27)=RKI
	ENDIF
C
C	CALCULATE PHOTKS
C
	IF (INDLIT.GT.0) THEN
C		! COEF ('#LIGHT') = FACTOR TO VARY OVERALL LIGHT INTENSITY
		F=COEF(INDLIT)*COEF(INDLIT+1)
	ELSE
		F=1.0
	ENDIF
	DO 110 J=1,NPHOTK
	RKI=0.0
	DO 112 I=1,NSOLWL
  112	RKI=RKI+SSDIST(I)*ABSQY(I,J)
 	COEF(IPHRK(J))=RKI*F
  110   CONTINUE
C
        RETURN
C
C     ENTRY to read in new APARM, BPARM, and EPARM data
C
      ENTRY NEWSOL
C
C --- USE FMTFLUXS.TSK IN 100,120 TO CREATE A TEMPORARPY FILE FROM
C     AN .OPO FILE.  
C     INCLUDE THIS TEMPORARY FILE AFTER THE .SOLPARM LINE IN THE
C     INT FILE
C ---------------------------------------------------------------
      I2=0
      DO 130 I=1,NSOLSD+1,7
         CALL INBUF ('NEWSOL(WL): ',12)
C         IF (I.EQ.1) THEN
C            WRITE (ICRT,*) '.SOLPARM INPUT ENCOUNTERED.  NEXT LINE IS:'
C            WRITE (ICRT,*) IOB160(1:76)
C         ENDIF
	 I1=I2+1
	 I2=I2+7
         IF (I2.GT.NSOLSD+1) I2=NSOLSD+1
         READ (IOB160,'(7F11.3)') (SD78(II),II=I1,I2)
         DO 120 II=I1,I2
            IF (SD78(II).NE.SOLWL(II)) THEN
                WRITE (ICRT,1211) SD78(II),SOLWL(II)
 1211  FORMAT ('WL FROM .INT(',F6.3,') DOES NOT MATCH WL FROM PROG(',
     1      F6.3,')')
                STOP
            ENDIF
  120    CONTINUE
  130 CONTINUE

      I2=0
      DO 140 I=1,NSOLSD,7
         CALL INBUF ('NEWSOL(A): ',11)
	 I1=I2+1
	 I2=I2+7
         IF (I2.GT.NSOLSD) I2=NSOLSD
         READ (IOB160,'(7E11.3)') (APARM(II),II=I1,I2)
  140 CONTINUE
      I2=0
      DO 150 I=1,NSOLSD,7
         CALL INBUF ('NEWSOL(B): ',11)
	 I1=I2+1
	 I2=I2+7
         IF (I2.GT.NSOLSD) I2=NSOLSD
         READ (IOB160,'(7F11.3)') (BPARM(II),II=I1,I2)
  150 CONTINUE
      I2=0
      DO 160 I=1,NSOLSD,7
         CALL INBUF ('NEWSOL(E): ',11)
	 I1=I2+1
	 I2=I2+7
         IF (I2.GT.NSOLSD) I2=NSOLSD
         READ (IOB160,'(7F11.5)') (EPARM(II),II=I1,I2)
  160 CONTINUE
      I2=0
      DO 170 I=1,NSOLSD,7
         CALL INBUF ('NEWSOL(F): ',11)
	 I1=I2+1
	 I2=I2+7
         IF (I2.GT.NSOLSD) I2=NSOLSD
         READ (IOB160,'(7F11.5)') (FPARM(II),II=I1,I2)
  170 CONTINUE
C      WRITE (ICRT,*) (SD78(II),II=1,NSOLSD+1)
C      WRITE (ICRT,*) (APARM(II),II=1,NSOLSD)
C      WRITE (ICRT,*) (BPARM(II),II=1,NSOLSD)
C      WRITE (ICRT,*) (EPARM(II),II=1,NSOLSD)
C      WRITE (ICRT,*) (FPARM(II),II=1,NSOLSD)
C
	NODARK=.TRUE.
	NOSD78=.TRUE.
C
	RETURN
	END
