C	SUBROUTINES SETPZ AND PZCALC FOR "INT" PROGRAM.  USED
C	TO CALCULATE SOLAR PHOTKS GIVEN INPUT OF PARAMETERS 
C	FITTING PHOTK AS F(Z).
C
C	SETPZ:  READS FIT PARAMETERS FROM FILE GIVEN ON P(Z)
C		INPUT LINE.  ARGUMENT = FILENAME
C
C	PZCALC:	CALCULATES PHOTKS GIVEN COSZ.  (COSZ IN COMMON)
C
C	
C ----------------------------------------------------------------------
	SUBROUTINE SETPZ (FZSFIL)
C
C	READS FIT PARAMETRS FROM .FZS FILE IN FZSFIL.
C	UNIT=TMP1 USED (OPENED, CLOSED)
C	CALLED BY MODL, RDCKC (FUTURE VERSIONS).  CALLS NOTHING
C
	CHARACTER FZSFIL*60
	INCLUDE 'MAINSPC.FOR'
	LOGICAL ERRIND
C
C
	IF (FZSFIL(1:1).EQ.' ') RETURN
C
C	OPEN FILE
C
	OPEN (UNIT=TMP1,FILE=FZSFIL,STATUS='OLD',ERR=5180)	! READONLY
	WRITE (OUT,*) ' Phot(Z) values read from file = ',
     &	 FZSFIL(1:LNBLNK(FZSFIL))
	IMETH=0
 5100	READ (TMP1,'(A)',END=5200) IOB160
	IF (IOB160(1:1).EQ.'!') THEN
		GOTO 5100
	ELSEIF (IOB160(1:12).EQ.'JZS LABEL  =') THEN
		IF (INTOUT) WRITE (OUT,*) ' ',IOB160(1:LNBLNK(IOB160))
	ELSEIF (IOB160(1:12).EQ.'OPT METHOD =') THEN
		IF (INTOUT) WRITE (OUT,*) ' ',IOB160(1:LNBLNK(IOB160))
		IF (IOB160(14:19).EQ.'AB    ') THEN
			IMETH=2
		ELSEIF (IOB160(14:19).EQ.'ABE   ') THEN
			IMETH=3
		ELSEIF (IOB160(14:17).EQ.'ABEF') THEN
			IMETH=4
		ELSE
			IMETH=0
			GOTO 5182
		ENDIF
	ELSE
		IF (IMETH.EQ.0) THEN
			WRITE (OUT,*) ' UNDEFNIED OPT METHOD'
			GOTO 5182
		ENDIF
		CALL PARSE0 (7,IOB160,80)
		CALL PARSE1 (1,IOBF16,I,8,IOB160)
		IF (IOBF16(1:1).EQ.' ') GOTO 5182
C
C		FIND WHICH PHOTK THIS IS.
C
		IF (NPHOTK.NE.0) THEN
			DO 5120 I=1,NPHOTK
			IF (PHOTNM(I).EQ.IOBF16(1:8)) THEN
				IPHOT=I
				GOTO 5150
			ENDIF
 5120			CONTINUE
		ENDIF
C
C		NOT A PHOTK.  IS IT ANOTHER VCOEF?  IF SO,
C		ADD IT TO LIST OF "PHOTOLYSIS REACTIONS"
C
		DO 5130 I=1,NCOEFV
		IF (COEFNM(I).EQ.IOBF16(1:8)) THEN
			IF (NPHOTK.EQ.MAXPHK) THEN
				WRITE (OUT,*) ' INCREASE MAXPHK'
				GOTO 5182
			ENDIF
			NPHOTK=NPHOTK+1
			IPHRK(NPHOTK)=I
			OLDPHK(NPHOTK)=0.0
			PHOTNM(NPHOTK)=IOBF16(1:8)
			IPHOT=NPHOTK
			GOTO 5150
		ENDIF
 5130		CONTINUE
C
C		OK IF IT'S NOT RECOGNIZED
C
		GOTO 5100
C
C		ADD PARAMETERS FOR THIS ZVCO
C
 5150		DO 5152 I=1,5
		CALL PARSER (I+1,ABSQY(I,IPHOT),ERRIND,IOB160)
		IF (ERRIND) GOTO 5182
 5152		CONTINUE
		CALL PARSEI (7,I,ERRIND,IOB160)
		IF (ERRIND.OR.I.EQ.0) THEN
			MVZCO(IPHOT)=IMETH
		ELSEIF (I.LT.0) THEN
			MVZCO(IPHOT)=-I
		ELSE
			MVZCO(IPHOT)=4
		ENDIF
		IF (INTOUT) WRITE (OUT,5153) IOBF16(1:8),
     &		 (ABSQY(I,IPHOT),I=1,4)
 5153		FORMAT (1X,'F(Z) PARMS FOR ',A8,' =',1P5E12.3)
C
	ENDIF
	GOTO 5100
C
C	ERRORS
C
 5180	WRITE (OUT,*) ' Specified phot(Z) file does not exist.'
	WRITE (ICRT,*) 'Phot(Z) file = ',FZSFIL(1:LNBLNK(FZSFIL)),
     &	 ' does not exist.'
	NERR=NERR+1
	GOTO 5201
C
 5182	WRITE (OUT,*) ' Error reading phot(z) file.',
     &	 '  Bad line = "',IOB160(1:LNBLNK(IOB160)),'"'
	WRITE (ICRT,*) 'Error reading phot(Z) file = ',
     &	 FZSFIL(1:LNBLNK(FZSFIL))
	NERR=NERR+1
C
C	DONE READING FILE
C
 5200	CLOSE (UNIT=TMP1)
 5201	RETURN
	END
C
C
C ----------------------------------------------------------------------
	SUBROUTINE PZCALC
C
C	CALCULATES PHOTKS WHOSE Z-FIT PARAMETERS WERE INPUT USING
C	SETPZ.  PHOTKS CALCULATED FOR COSZ, WHICH IS IN COMMON
C	PARAMETERS AND RESULTS ARE ALSO IN COMMONS.
C
C	NO FILE ACTIVITY EXCEPT ERROR MESSAGES TO UNIT=OUT.
C	CALLED BY NEWPHK.  CALLS NOTHING
C
C	FITTING PARAMETERS USED:
C
C		    A = ABSQY(1,*)
C		    B = ABSQY(2,*)
C		    E = ABSQY(3,*)	(ZERO FOR METH=2)
C		    F = ABSQY(4,*)	(USED ONLY IF METH=4)
C		CZLOW = ABSQY(5,*)	(USED ONLY IF METH=4)
C
C	THE FOLLOWING FUNCTION IS USED CALCULATE PHOTKS GIVING
C	THE FITTING PARAMETERS.
C
C	PHOTK(COSZ) = A*EXP(-B*SQRT((1.0+E)/((COSZ**2)+E)))
C
C	IF METH=4 AND COSZ < CZLOW, THEN PHOTK CALCULATED BY
C
C	PHOTK(COSZ) = PHOTK(CZLOW)*((COSZ/CZLOW)**F)
C
C
	INCLUDE 'MAINSPC.FOR'
	LOGICAL WARN,ERRIND
	DATA WARN/.TRUE./
C
C
C	SET ALL PHOTKS TO 0 IF COSZ OUT OF RANGE
C
	IF (NPHOTK.EQ.0) RETURN
	IF (COSZ.LE.0.0.OR.COSZ.GT.1.0) THEN
		IF (COSZ.NE.0.0.AND.WARN) THEN
			WRITE (OUT,*) '**BAD COSZ ON CALL TO PZCALC: ',
     &			 COSZ
			NERR=NERR+1
			WARN=.FALSE.
		ENDIF
		DO 10 I=1,NPHOTK
   10		COEF(IPHRK(I))=0.0
		RETURN
	ENDIF
C
	COSZ2=COSZ*COSZ
C
C	CALC FIT.  IF IMETH=0, GIVE WARNING (IF NOT DONE BEFORE)

	ERRIND=.FALSE.
	DO 20 IPHOT=1,NPHOTK
	IMETH=MVZCO(IPHOT)
	IF (IMETH.EQ.0) THEN
		IF (WARN) THEN
			WRITE (OUT,*) '** PHOTK(',
     &			 PHOTNM(IPHOT)(1:LNBLNK(PHOTNM(IPHOT))),
     &			 ') UNDEFINED.  SET TO ZERO.'
			WRITE (ICRT,*) '** PHOTK(',
     &			 PHOTNM(IPHOT)(1:LNBLNK(PHOTNM(IPHOT))),
     &			 ') UNDEFINED.  SET TO ZERO.'
			WRITE (ICRT,*)
			ERRIND=.TRUE.
		ENDIF
		COEF(IPHRK(IPHOT))=0.0
	ELSEIF (IMETH.EQ.2) THEN
		COEF(IPHRK(IPHOT))=ABSQY(1,IPHOT)*EXP(-ABSQY(2,IPHOT)/
     &		 COSZ)
	ELSEIF (IMETH.EQ.3.OR.(IMETH.EQ.4.AND.COSZ.GE.ABSQY(5,IPHOT)))
     &	 THEN
		COEF(IPHRK(IPHOT))=ABSQY(1,IPHOT)*EXP(-ABSQY(2,IPHOT)*
     &		 SQRT((1.0+ABSQY(3,IPHOT))/(COSZ2+ABSQY(3,IPHOT))))
	ELSEIF (IMETH.EQ.4.AND.(COSZ.LT.ABSQY(5,IPHOT))) THEN
		COEF(IPHRK(IPHOT))=ABSQY(1,IPHOT)*EXP(-ABSQY(2,IPHOT)*
     &		 SQRT((1.0+ABSQY(3,IPHOT))/((ABSQY(5,IPHOT)**2)+
     &		 ABSQY(3,IPHOT))))*
     &		 ((COSZ/ABSQY(5,IPHOT))**ABSQY(4,IPHOT))
	ELSE
		IF (WARN) THEN
			WRITE (OUT,*) '** PHOTK(',
     &			 PHOTNM(IPHOT)(1:LNBLNK(PHOTNM(IPHOT))),
     &			 ') HAS UNRECOGNIZED OPT METHOD = ',IMETH
			WRITE (ICRT,*) '** PHOTK(',
     &			 PHOTNM(IPHOT)(1:LNBLNK(PHOTNM(IPHOT)))
     &			 ,') HAS UNRECOGNIZED OPT METHOD = ',IMETH
			ERRIND=.TRUE.
		ENDIF
		COEF(IPHRK(IPHOT))=0.0
	ENDIF
   20	CONTINUE
C
C	DON'T REPEAT WARNINGS FOR INDIVIDUAL REACTIONS AGAIN
C
	IF (ERRIND) WARN=.FALSE.
C
	RETURN
	END
