	PROGRAM CDA2CSV
C
C	PRODUCES A .CSV FILE FROM A .CDA FILE.
C	ONLY OUTPUTS 250 COLUMNS.  IF MORE THAN THAT, FIRST DELETES CHANNELS
C	WITH ALL ZEROS, THEN THOSE WITH SMALLEST MAGNITUDE MAXIMA.
C
C	OPTIONALLY FOR SPECIES LISTED IN AN INPUT FILE
C	IF SPECIES LISTING INPUT FILE NOT GIVEN, SAVES ALL NON-ZERO SPECIES
C	IF SPECIES LISTING INPUT FILE IS GIVEN, SAVES ALL LISTED SPECIES,
C		WITH BLANKS FOR THOSE NOT FOUND
C	OUTPUT TO TMP.CSV
C
C	MODELING.PRM OPTIONS:
C
	PARAMETER (MAXCHN=5000,MAXOUT=250)
	CHARACTER*16 NAME(MAXCHN),NAMSAV(MAXCHN),OUTDAT(MAXOUT)
	INTEGER ORDR(MAXCHN),LNAMSV(MAXCHN)
	REAL*4 T,DATA(MAXCHN),MAXDAT(MAXCHN)
	CHARACTER INPNAM*8,PRMNAM*8,OUTFIL*80,INFILE*80,DATCAL*16
C
	LOGICAL ERRIND,SAVALL
	CHARACTER CDTUIC*60,INLIN*80,RUNLBL*80,MODLBL*16
	CHARACTER FILNAM*80,NOCHR*6,SAVFIL*80
	CHARACTER INPFIL*8,PRMFIL*8,MODFIL*8
C
C	READ COMMAND LINE
C
	CALL GETARG(1,INLIN)
	IF (INLIN(1:1).EQ.' '.OR.INLIN(1:1).EQ.'?') THEN
		WRITE (6,*) 'Produces a CSV file from a CDA file'
		WRITE (6,*) 'Use: CDA2CSV runid [modelid] [outfile]'//
     &		 '[SAVE=listfile]'
		WRITE (6,*) '     runid = Run ID'
		WRITE (6,*) '     modelid = model (.PRM) location'
     &		 //' (default=CALCS)'
		WRITE (6,*) '     outfile = CSV output file (defa'
     &		 //'ult is TMP, so file is .\TMP.CSV'
		WRITE (6,*) '     SAVE=lisfile. Get names of species'
     &		 //' to use in lisfile (full file name)'
		CALL EXIT
	ENDIF
C
	CALL GETARG (2,PRMFIL)
	IF (PRMFIL(1:1).EQ.' ') THEN
		PRMFIL='CALCS'
		L=5
	ELSE
		L=LNBLNK(PRMFIL)
	ENDIF
	LINFIL=LNBLNK(INLIN)
	INFILE=PRMFIL(1:L)//'\'//INLIN(1:LINFIL)
	LINFIL=L+LINFIL+1
C
	SAVALL=.TRUE.
	OUTFIL='TMP.CSV'
	LOUTFL=7
C
	IARG=3
    7	CALL GETARG(IARG,INLIN)
	IF (INLIN(1:1).EQ.' ') THEN
		GOTO 8
	ELSEIF (INLIN(1:5).EQ.'SAVE=') THEN
		SAVFIL=INLIN(6:)
		SAVALL=.FALSE.
	ELSEIF (IARG.EQ.3) THEN
		LOUTFL=LNBLNK(INLIN)
		OUTFIL=INLIN(1:LOUTFL)//'.CSV'
		LOUTFL=LOUTFL+4
	ELSE
		WRITE (6,*) 'Unrecognized option: '//INLIN(1:LNBLNK(INLIN))
		CALL EXIT
	ENDIF
	IARG=IARG+1
	GOTO 7
   8	CONTINUE
C
C	GET PARMS FROM MODELING.PRM
C
	OPEN (UNIT=1,FILE='MODELING.PRM',STATUS='UNKNOWN')
C
	CDTUIC=' '
C
   10	READ (1,'(A)',END=18) INLIN
	IF (INLIN(1:4).EQ.'CAL=') THEN
		CDTUIC=INLIN(5:)
	ENDIF
	IF (CDTUIC(1:1).EQ.' ') CDTUIC='.\'
	LCDTUC=LNBLNK(CDTUIC)
	GOTO 10
C
  18	CLOSE (UNIT=1)
C
C	OPEN INPUT FILE AND READ INITIAL RECORDS.
C
	FILNAM=CDTUIC(1:LCDTUC)//INFILE(1:LINFIL)//'.CDA'
	LFIL=LNBLNK(FILNAM)
C
	OPEN (UNIT=1,FILE=FILNAM,ERR=900,STATUS='OLD',ACTION='READ')
	READ (1,101,ERR=910) INLIN(1:2),N,INPFIL,PRMFIL,MODFIL,DATCAL,
     &	 RUNLBL
	IF (N.GT.MAXCHN) STOP 'INCREASE MAXCHN IN CDA2CSV'
	IF (INLIN(1:2).NE.'A8') THEN
		WRITE (6,*) 'This program only supports CDA files with '
     &		 //'format code "A8".'
		GOTO 990
	ENDIF
	READ (1,102,ERR=912,END=912) (NAME(I),I=1,N)
  101	FORMAT(A2,I5,3(1X,A8),1X,A16,1X,A)
  102	FORMAT (8A11)
  103	FORMAT (F10.2/(1PE10.3,7E11.3))
C
C	FIND WHICH NAMES ARE TO BE SAVED
C
	IF (SAVALL) THEN
		IF (N.GT.MAXOUT) THEN
C		IF TOO MANY CHANNELS TO OUTPUT. PASS THROUGH AND DELETE ZERO CHANNELS
			SAVALL=.FALSE.
			NSAV=0
			DO 210 I=1,N
			ORDR(I)=0
  210			MAXDAT(I)=0.0
  220			READ (1,103,END=224,ERR=914) T,(DATA(I),I=1,N)
			DO 222 I=1,N
			IF (ABS(DATA(I)).GT.MAXDAT(I)) MAXDAT(I)=ABS(DATA(I))
  222			CONTINUE
			GOTO 220
  224			REWIND (UNIT=1)
			DO 225 I=1,CEILING(FLOAT(N)/8.0)+1
  225			READ (1,*)
C
  230			DO 232 I=1,N
			IF (MAXDAT(I).NE.0.0) THEN
				NSAV=NSAV+1
				ORDR(I)=1
			ENDIF
  232			CONTINUE
C
C			IF STILL TOO MANY CHANNELS, GET RID OF SMALLEST ONES
  240			IF (NSAV.LT.MAXOUT) GOTO 245
			IMIN=0
			DO 242 I=1,N
			IF (ORDR(I).GT.0) THEN
				IF ((IMIN.EQ.0).OR.(MAXDAT(I).LT.
     &				 DATMIN)) THEN
					DATMIN=MAXDAT(I)
					IMIN=I
				ENDIF
			ENDIF
  242			CONTINUE
			ORDR(IMIN)=0
			NSAV=NSAV-1
			GOTO 240
C
  245			NSAV=0
			DO 246 I=1,N
			IF (ORDR(I).GT.0) THEN
				NSAV=NSAV+1
				ORDR(NSAV)=I
				NAMSAV(NSAV)=NAME(I)
			ENDIF
  246			CONTINUE
		ENDIF
C
	ELSE
		FILNAM=SAVFIL
		LFIL=LNBLNK(FILNAM)
		OPEN (UNIT=3,FILE=FILNAM,STATUS='OLD',ACTION='READ',
     &		 ERR=900)
		NSAV=0
  152		READ (3,'(A)',END=155) INLIN
		IF (INLIN(1:1).EQ.' '.OR.INLIN(1:1).EQ.'!') GOTO 152
		IF (NSAV.EQ.MAXOUT) GOTO 155
		NSAV=NSAV+1
		NAMSAV(NSAV)=INLIN(1:16)
		ORDR(NSAV)=0
		DO 156 I=1,N
		IF (INLIN(1:10).EQ.NAME(I)(1:10)) THEN
			ORDR(NSAV)=I
			GOTO 152
		ENDIF
  156		CONTINUE
		ORDR(NSAV)=I
		IF (NSAV.LT.MAXOUT) GOTO 152
  155		CLOSE (UNIT=3)
		IF (NSAV.EQ.0) THEN
			WRITE (6,*) 'No species listed in CSVSAVE file ',
     &			 FILNAM(1:LFIL)
			GOTO 990
		ENDIF
C
  164		CONTINUE
	ENDIF
C
C	CREATE NAME LIST
C
	IF (SAVALL) THEN
		NSAV=N
		DO 160 I=1,N
		LFIL=LNBLNK(NAME(I))
		OUTDAT(I)=',"'//NAME(I)(1:LFIL)//'"'
  160		LNAMSV(I)=LFIL+3
	ELSE
		DO 162 J=1,NSAV
		LFIL=LNBLNK(NAMSAV(J))
		OUTDAT(J)=',"'//NAMSAV(J)(1:LFIL)//'"'
		LNAMSV(J)=LFIL+3
  162		CONTINUE
	ENDIF
C
C	OPEN OUTPUT FILE AND WRITE INITIAL RECORDS
C
	OPEN (UNIT=2,FILE=OUTFIL,STATUS='UNKNOWN')
C
	WRITE (2,141) INPFIL,PRMFIL,DATCAL,RUNLBL,MODFIL,NSAV,
     &	 (OUTDAT(I)(1:LNAMSV(I)),I=1,NSAV)
  141	FORMAT ('Calc   ,',A8,',',A8,',',A16/'Label  ,',A/'Model  ,',A/
     &   'Species,',I5//'Time ',1000A)
C
C	LOOP OVER RECORDS.  
C
  120	READ (1,103,END=200) T,(DATA(I),I=1,N)
	IF (SAVALL) THEN
		WRITE (2,123) T,(DATA(I),I=1,N)
  123		FORMAT (F7.1,1000(",",1PE10.3))
	ELSE
		DO 121 I=1,NSAV
		IF (ORDR(I).GT.0) THEN
			WRITE (OUTDAT(I),'(",",1PE10.3)') DATA(ORDR(I))
			LNAMSV(I)=11
		ELSE
			OUTDAT(I)=','
			LNAMSV(I)=1
		ENDIF
  121		CONTINUE
		WRITE (2,142) T,(OUTDAT(I)(1:LNAMSV(I)),I=1,NSAV)
  142		FORMAT (F7.1,1000A)
	ENDIF
	GOTO 120
C
  200	CLOSE (UNIT=1)
	CLOSE (UNIT=2)
	WRITE (6,*) 'File = '//OUTFIL(1:LOUTFL)//' created.'
	CALL EXIT
C
C	ERRORS
C
  900	WRITE (6,*) 'File = '//FILNAM(1:LFIL)//' does not exist.'
	GOTO 990
  910	WRITE (6,*) 'Error reading headers from file = '
     &	 //FILNAM(1:LFIL)	
	GOTO 990
  912	WRITE (6,*) 'Error reading names from file = '
     &	 //FILNAM(1:LFIL)	
	GOTO 990
  914	WRITE (6,*) 'Error reading data from file = '
     &	 //FILNAM(1:LFIL)	

C
  990	CALL EXIT (2)
	END
