C	LMPEMI.FTN
C
C	SUBROUTINE TO CONVERT EMISSIONS COMPOSITIONS (IN TERMS OF SAROAD
C	SPECIES AND MASS AMOUNTS) TO MODEL SPECIES COMPOSITIONS (IN
C	TERMS OF MODEL SPECIES NAMES AND MOLES/KG EMITTED), USING
C	SPECIATION IN SAROAD.PRM (IN COMMONS).
C
C	7/90 SAROAD FILE FORMAT (NO KOH ASSIGNMENTS).
C
	SUBROUTINE LMPEMI (OUTU,IUNIT,MAXNMS,NMS,MSNAM,MSLVL,MSNC,
     &	 MSWT,INDNOR,TOTMOL,TOTC,TOTWT,UNKWT)
C
C	ARGUMENTS:
C		OUTU	UNIT FOR DIAGNOSTIC AND SUMMARY OUTPUT (OPEN)
C			(IF OUTU=0, NO OUTPUT).
C		IUNIT	UNIT TO READ COMPOSITION DATA (OPEN)
C			(IF IUNIT=0, READS FROM INBUF)
C
C		MAXNMS	MAX. NO DETAILED MODEL SPECIES INPUT
C		NMS	NO. DETAILED MODEL SPECIES INPUT.
C		MSNAM	MODEL SPECIES NAME
C		MSLVL	MOLES MODEL SPECIES
C		MSNC	MOLES CARBON MODEL SPECIES (CONVERTED TO C/MOLE
C			JUST BEFORE RETURNING)
C		MSWT	MASS MODEL SPECIES.  (CONVERTED TO MWT JUST
C			BEFORE RETURNING)
C
C		TOTMOL	TOTAL MOLES EMITTED
C		TOTC	TOTAL CARBONS EMITTED
C		TOTWT	TOTAL MASS EMITTED
C		UNKWT	UNKNOWN MASS EMITTED
C
C		INDNOR	NORMALIZATION CODE:
C			0 = ASK USER IF NORMALIZATION IS DESIRED.
C			1 = NORMALIZE (TO 1 PPMC NMHC BY DEFAULT)
C			2 = DO NOT NORMALIZE
C			3 = NORMALIZE TO 1 GRAM
C			4 = NORMALIZE TO 1 C
C
C	OUTPUT BUT NOT RETURNED
C
C		TOTHC	TOTAL MOLES C NMHC (OUTPUT BUT NOT RETURNED)
C
C	NORMAZIZATION OPTIONS:
C		"NORM=G"  ..  NORMALIZES TO 1 GRAM (OF "FAC" GRAMS)
C		"NORM=N"  ..  DO NOT NORMALIZE.  
C		"NORM=NMHC"   NORMALIZE TO 1 C OTHER THAN METHANE OR CO
C			      (DEFAULT)
C		"NORM=C"  ..  NORMALIZE TO 1 CARBON.
C		"FAC=value"   MULTIPLY ALL RESULTS BY THIS VALUE.
C
	INTEGER OUTU,IUNIT,NMS
	CHARACTER*8 MSNAM(MAXNMS)
	REAL*4 MSLVL(MAXNMS),TOTMOL,TOTC,TOTWT,UNKWT,MSNC(MAXNMS),
     &	 MSWT(MAXNMS)
C
C
C	GENERAL SPECIFICATIONS
C
	INCLUDE 'LUMPSPEC.FOR'
C
C	SPECIFICATIONS OF DETAILED MODEL SPECIES ASSIGNMENTS FOR
C	SAROAD CLASSES (FROM SAROAD.PRM)
C
	INCLUDE 'SARSPEC.FOR'
C
C
C	EMISSIONS DATA (INPUT):
C
C	FOR EACH SAROAD SPECIES:
C	EMISAR	... SAROAD NO. OF EMISSIONS
C	EMIWT	... UNNORMALIZED MASS DISTRIBUTION OF EMISSIONS
C
	INTEGER*4 EMISAR
	REAL*4 EMIWT
C
C	UNKNOWNS
C
	PARAMETER (MAXUNK=100)
	INTEGER*4 UNKSAR(MAXUNK)
	REAL*4 UNKWTI(MAXUNK)
C
	LOGICAL ERRIND
	CHARACTER*80 INLIN
C
	LOGICAL NORMC,NORMW,NORNMC
C
C	INITIALIZE MODEL SPECIES DATA
C
	NMS=0
	TOTWT=0.0
	UNKWT=0.0
	TOTMOL=0.0
	TOTC=0.0
	IF (OUTU.NE.0) WRITE (OUTU,1) '!'
    1	FORMAT (A)
C
	NUNK=0
C
C
C	READ NEXT EMISSIONS SAROAD, MASS FROM UNIT=IUNIT
C
	FAC=1.0
	NORNMC=.TRUE.
	NORMC=.FALSE.
	NORMW=.FALSE.
C
 100	IF (IUNIT.EQ.0) THEN
		CALL INBUF ('SARDAT:',8)
		IF (IORET.EQ.2) GOTO 200
		INLIN=IOB160(1:80)
	ELSE
		READ (IUNIT,1,END=200) INLIN
	ENDIF
	IF (INLIN(1:1).EQ.'!') THEN
		GOTO 100
	ELSEIF (INLIN(1:2).EQ.'. ') THEN
		GOTO 200
C
	ELSEIF (INLIN(1:4).EQ.'FAC='.OR.INLIN(1:4).EQ.'#FAC') THEN
C
C		FAC=factor.    NUMBER OF PPMC TOTAL OUTPUT
C
		CALL PARSE0 (2,INLIN,80)
		CALL PARSER (2,FAC,ERRIND,INLIN)
		IF (ERRIND) GOTO 800
C		IF (FAC.EQ.0.0) WRITE (6,*) 'WARNING:  FAC=0.  DATA',
C     &		 ' IGNORED UNTIL NEXT ''FAC='' RECORD.'
		GOTO 100
C
	ELSEIF (INLIN(1:5).EQ.'NORM=') THEN
		IF (INLIN(6:6).EQ.'G') THEN
			NORMW=.TRUE.
			NORMC=.FALSE.
			NORNMC=.FALSE.
		ELSEIF (INLIN(6:7).EQ.'N ') THEN
			NORMW=.FALSE.
			NORMC=.FALSE.
			NORNMC=.FALSE.
		ELSEIF (INLIN(6:6).EQ.'C') THEN
			NORMW=.FALSE.
			NORMC=.TRUE.
			NORNMC=.FALSE.
		ELSEIF (INLIN(6:9).EQ.'NMHC') THEN
			NORMW=.FALSE.
			NORMC=.FALSE.
			NORNMC=.TRUE.
		ELSE
			WRITE (6,*) 'UNRECOGNIZED NORMALIZATION ',
     &			 'OPTION (',INLIN(6:9),') IGNORED.'
		ENDIF
		GOTO 100
C
	ELSEIF (FAC.EQ.0.0) THEN
		GOTO 100
	ENDIF
C
	READ (INLIN,'(I5)',ERR=800) EMISAR
	IF (EMISAR.EQ.0) GOTO 100
	CALL PARSE0 (2,INLIN,80)
	CALL PARSER (2,EMIWT,ERRIND,INLIN)
	IF (ERRIND) GOTO 800
	IF (EMIWT.EQ.0.0) GOTO 100
	EMIWT=EMIWT*FAC
C
	TOTWT=TOTWT+EMIWT
C
C
C	DETERMINE WHICH MODEL SPECIES THIS SAROAD CLASS
C	CORRESPONDS TO.
C
	DO 102 ISAR=1,NSP
	IF (SAR(ISAR).EQ.EMISAR) GOTO 104
  102	CONTINUE
C
C	NOT FOUND.  ADD TO UNKNOWNS.  IF TOO MANY, OVER=WRITE LOWEST.
C
	UNKWT=UNKWT+EMIWT
	IF (NUNK.EQ.MAXUNK) THEN
		X=UNKWT
		II=0
		DO 1051 I=1,NUNK
		IF (UNKWTI(I).LT.X) THEN
			II=I
			X=UNKWTI(I)
		ENDIF
 1051		CONTINUE
		UNKSAR(II)=EMISAR
		UNKWTI(II)=EMIWT
	ELSE
		NUNK=NUNK+1
		UNKSAR(NUNK)=EMISAR
		UNKWTI(NUNK)=EMIWT
	ENDIF
	GOTO 100
C
C
C	THIS EMITTED GROUP FOUND ON SAROAD.PRM AS ENTRY NO. ISAR.
C
C	LOOP OVER MODEL SPECIES USED FOR THIS SAROAD NO.
C	SEE IF THIS MODEL SPECIES ON LIST, AND IF NOT ADD IT
C	THEN ADD AMOUNT EMITTED (CONVERTED TO MOLES) TO TOTAL
C	FOR THIS MODEL SPECIES.
C
  104	IF (IMIX(ISAR).GT.0) THEN
C
C		ONE COMPOUND OR SIMPLE ISOMERIC MIXTURE.
C		NOTE LVL ASSUMED TO BE MOLE FRACTIONS.
C
		FMOL=EMIWT/SARMW(ISAR)
C
		DO 110 IMOD=IMIX(ISAR),NMIX(ISAR)
		F=LVL(IMOD)*FMOL
		IF (F.EQ.0.0) GOTO 110
		TOTMOL=TOTMOL+F
		TOTC=TOTC+(F*SARNC(ISAR))
		IF (NMS.GT.0) THEN
			DO 112 I=1,NMS
			IF (SPCLAS(IMOD).EQ.MSNAM(I)) THEN
				MSLVL(I)=MSLVL(I)+F
				MSNC(I)=MSNC(I)+(F*SARNC(ISAR))
				MSWT(I)=MSWT(I)+(EMIWT*LVL(IMOD))
				GOTO 110
			ENDIF
  112			CONTINUE
		ENDIF
		NMS=NMS+1
		IF (NMS.GT.MAXNMS) GOTO 810
		MSNAM(NMS)=SPCLAS(IMOD)
		MSLVL(NMS)=F
		MSNC(NMS)=F*SARNC(ISAR)
		MSWT(NMS)=EMIWT*LVL(IMOD)
  110		CONTINUE
C
	ELSE
C
C		COMPLEX NON-ISOMERIC MIXTURE.  NOTE WLVL ASSUMED
C		TO BE WEIGHT FRACTIONS.
C
		DO 120 IMOD=-IMIX(ISAR),NMIX(ISAR)
		F=EMIWT*WLVL(IMOD)
		IF (F.EQ.0.0) GOTO 120
		TOTMOL=TOTMOL+F
		TOTC=TOTC+(F*NCMIX(IMOD))
		IF (NMS.GT.0) THEN
			DO 122 I=1,NMS
			IF (SPCLSM(IMOD).EQ.MSNAM(I)) THEN
				MSLVL(I)=MSLVL(I)+F
				MSNC(I)=MSNC(I)+(F*NCMIX(IMOD))
				MSWT(I)=MSWT(I)+(F*MWMIX(IMOD))
				GOTO 120
			ENDIF
  122			CONTINUE
		ENDIF
		NMS=NMS+1
		IF (NMS.GT.MAXNMS) GOTO 810
		MSNAM(NMS)=SPCLSM(IMOD)
		MSLVL(NMS)=F
		MSNC(NMS)=F*NCMIX(IMOD)
		MSWT(NMS)=F*MWMIX(IMOD)
  120		CONTINUE
C
	ENDIF
C
C	CALCULATE MOLES C NMHC BY SUBTRACTING 'METHANE' AND 'CO'
C	FROM TOTAL CARBONS
C
	TOTHC=TOTC
	DO 115 I=1,NMS
	IF (MSNAM(I).EQ.'METHANE '.OR.MSNAM(I).EQ.'CO      ') 
     &	 TOTHC=TOTHC-MSLVL(I)
  115	CONTINUE

C	LOOP BACK FOR NEXT EMISSIONS INPUT
C
	GOTO 100
C
C
C	SEE IF NORMALIZATION TO BE DONE.
C
  200	IF (INDNOR.EQ.0) THEN
  230		WRITE (ICRT,231)
  231		FORMAT ('$Normalize to one mole NMHC (y/n, default=no)? ')
		READ (IKEY,1,END=9999) INLIN
C
		IF (INLIN(1:1).EQ.'N'.OR.INLIN(1:1).EQ.'n'.OR.
     &		 INLIN(1:1).EQ.' ') THEN
			INDNOR=2
		ELSEIF (INLIN(1:1).EQ.'Y'.OR.INLIN(1:1).EQ.'y') THEN
			INDNOR=1
		ELSE
			GOTO 230
		ENDIF
	ENDIF
	IF (INDNOR.EQ.1) THEN
		NORMW=.FALSE.
		NORMC=.FALSE.
		NORNMC=.TRUE.
	ELSEIF (INDNOR.EQ.3) THEN
		NORMW=.TRUE.
		NORMC=.FALSE.
		NORNMC=.FALSE.
		INDNOR=1
	ELSEIF (INDNOR.EQ.4) THEN
		NORMW=.FALSE.
		NORMC=.TRUE.
		NORNMC=.FALSE.
		INDNOR=1
	ELSE
		INDNOR=2
	ENDIF
C
C	NORMALIZE (IF APPLICABLE) AND OUTPUT SUMMARY DATA
C
	UNKTOT=UNKWT
	IF (OUTU.NE.0.AND.UNKWT.NE.0.0) WRITE (OUTU,*) '!'
	IF (INDNOR.EQ.1) THEN
		IF (NORMC) THEN
			IF (TOTC.EQ.0.0) THEN
				WRITE (ICRT,*) 'Cannot be normalized.'
				INDNOR=2
				GOTO 2399
			ENDIF
			IF (OUTU.NE.0) WRITE (OUTU,2341) FAC
 2341			FORMAT ('! Normalized to give ',1PG12.3,' carbons.')
			FAC=FAC/TOTC
		ELSEIF (NORNMC) THEN
			IF (TOTHC.EQ.0.0) THEN
				WRITE (ICRT,*) 'Cannot be normalized.'
				INDNOR=2
				GOTO 2399
			ENDIF
			IF (OUTU.NE.0) WRITE (OUTU,2342) FAC
 2342			FORMAT ('! Normalized to give ',1PG12.3,' NMHC''s.')
			FAC=FAC/TOTHC
		ELSEIF (NORMW) THEN
			IF (TOTWT.EQ.0.0) THEN
				WRITE (ICRT,*) 'Cannot be normalized.'
				INDNOR=2
				GOTO 2399
			ENDIF
			IF (OUTU.NE.0) WRITE (OUTU,2343) FAC
 2343			FORMAT ('! Normalized to give ',1PG12.3,' grams.')
			FAC=FAC/TOTWT
		ENDIF
		IF (OUTU.NE.0) WRITE (OUTU,2344) FAC
 2344		FORMAT ('! Factor = ',1PG12.3/'!')
		DO 234 I=1,NMS
		MSNC(I)=MSNC(I)*FAC
		MSWT(I)=MSWT(I)*FAC
  234		MSLVL(I)=MSLVL(I)*FAC
		TOTMOL=TOTMOL*FAC
		TOTC=TOTC*FAC
		TOTWT=TOTWT*FAC
		UNKWT=UNKWT*FAC
		TOTHC=TOTHC*FAC
	ENDIF
 2399	CONTINUE
C
	IF (OUTU.NE.0) THEN
		IF (INDNOR.EQ.1) THEN
			IF (OUTU.NE.0) WRITE (OUTU,220) TOTWT,
     &			 UNKWT/TOTWT,TOTMOL,TOTC,NMS
		ELSE
			IF (OUTU.NE.0) WRITE (OUTU,221) TOTWT,
     &			 UNKWT/TOTWT,TOTMOL,TOTC,NMS
		ENDIF
	ENDIF
  220	FORMAT ('! Total wt. (g)           =',0PF8.3
     &         /'! Wt. percent of unknowns =',2PF8.3,
     &                  '  (See below for list)'
     &         /'! Total number of moles   =',0PF8.4
     &         /'! Total number of moles C =',F8.4
     &         /'! No. model species used  =',I5)
  221	FORMAT ('! Total wt. (g)           =',1PE10.3
     &         /'! Wt. percent of unknowns =',2PF8.3
     &         /'! Total number of moles   =',1PE10.3
     &         /'! Total number of moles C =',E10.3
     &         /'! No. model species used  =',I5)
C
C
C	CHECK FOR PROPER NORMALIZATION BY SUMMING UP MASS AND
C	MOLE C FROM MODEL SPECIES
C
C	ALSO CONVERT MSNC AND MSWT TO CARBONS, MASS PER MOLE
C
	IF (TOTC.NE.0.0.AND.(TOTWT-UNKWT).NE.0.0) THEN
		CHKNC=0.0
		CHKWT=0.0
		DO 300 I=1,NMS
		CHKNC=CHKNC+MSNC(I)
		CHKWT=CHKWT+MSWT(I)
		MSNC(I)=MSNC(I)/MSLVL(I)
  300		MSWT(I)=MSWT(I)/MSLVL(I)
C
		CHKNC=(TOTC-CHKNC)/TOTC
		CHKWT=(TOTWT-UNKWT-CHKWT)/(TOTWT-UNKWT)
		I=0
		IF (ABS(CHKNC).GT.1.E-5) THEN
			WRITE (6,301) CHKNC
			IF (OUTU.NE.0) WRITE (OUTU,301) CHKNC
  301			FORMAT ('!'/'! WARNING!  Normalization error = ',
     &                   2PF8.2,'% for total no. Carbons.'/'!')
			I=1
		ENDIF
		IF (ABS(CHKWT).GT.1.E-5) THEN
			WRITE (6,302) CHKWT
			IF (OUTU.NE.0) WRITE (OUTU,302) CHKWT
  302			FORMAT ('!'/
     &                   '! WARNING!  Normalization error = ',
     &                   2PF8.2,'% for total assigned mass.'/'!')
			I=1
		ENDIF
		IF (I.EQ.0.AND.OUTU.NE.0) WRITE (OUTU,303)
  303		FORMAT ('! Normalization checked OK.'/'!')
	ENDIF
C
C	WRITE LIST OF UNKNOWNS, IN ORDER
C
	IF (NUNK.NE.0.AND.OUTU.NE.0) THEN
		WRITE (OUTU,310)
  310		FORMAT ('! ------------'/'! Unknowns'/'! ID       %')
		N=0
 3100		X=0.0
		II=0
		DO 3101 I=1,NUNK
		IF (UNKWTI(I).GT.X) THEN
			X=UNKWTI(I)
			II=I
		ENDIF
 3101		CONTINUE
		IF (II.NE.0) THEN
			WRITE (OUTU,'(''!'',I6,2PF6.1)') UNKSAR(II),
     &			 UNKWTI(II)/UNKTOT
			UNKWTI(II)=0.0
			N=N+1
			IF (N.LT.NUNK) GOTO 3100
		ENDIF
		WRITE (OUTU,'(''! ------------''/''!'')')
	ENDIF
C
C	DONE
C
C@@	OUTPUT FILE WITH DMS'S
C
C@	OPEN (UNIT=8,FILE='LMPEMI.TMP',STATUS='UNKNOWN')
C@	WRITE (8,'(A8,1PE12.4,0P2F10.3)') (MSNAM(I),MSLVL(I),
C@     &	 MSNC(I),MSWT(I),I=1,NMS)
C@	CLOSE (UNIT=8)
C@	WRITE (6,*) 'LMPEMI.TMP CREATED WITH DMS ASSIGNMENTS'
C@@
C
	RETURN
C
C	ERROR READING DATA.  INDICATE NO MODEL SPECIES PRODUCED.
C
  800	WRITE (6,*) 'Error in reading emissions data.'
	WRITE (6,*) 'Bad line: "',INLIN(1:LNBLNK(INLIN)),'"'
	NMS=0
	RETURN
  810	STOP 'Dimension overrun.  Increase MAXNMS in PRPEMI.FOR.'
C
 9999	STOP 'ABORTED'
	END
