C	RDOLEP.FTN
C
C	READS MODEL SPECIES AND KINETIC AND MECHANISTIC PARAMETERS IN THE
C	FORMAT FOR LUMPED ALKENES
C
	SUBROUTINE RDOLEP (FUNIT)
C
C	ARGUMENT:  FILE UNIT FOR INPUT
C
	INTEGER FUNIT
C
	INCLUDE 'LUMPSPEC.FOR'
C
	PARAMETER (NOLEPM=20,NOLSUB=8,NNIT=9,NGLA=10,NETHE=11,NKO3=12)
	LOGICAL FIRST,ERRIND,RKPPM
	INTEGER SUBIND(2),PRMLOC(NOLEPM)
C
	CHARACTER*2 OLEPNM(NOLEPM)
	CHARACTER INLIN*80,NAMEIN*8
C
	DATA OLEPNM/'P1','P2','P3','P4','P5','P6','P7','P8',
     &	 'PN','GA','ET','O3','*3','*4','N3','*5','*6','OA','*7','*8'/
C
C	THE FIRST NOLSUB 'OLEFIN' PARAMETERS REFER TO NUMBERS OF DIFFERENT
C	TYPES OF SUBSTITUENTS.  THE NNIT'TH IS THE NITRATE YIELD IN THE
C	OH REACTION.  THE NKO3+'TH ARE THE O3, NO3, AND O3P RATE CONSTANTS, 
C	WHICH ARE TREATED AS PARAMETERS.
C	THE NGLA'TH PARM IS THE "GLYCOLALDEHYDE" YIELD, WHICH IS
C	USED WHEN LUMPING ETHENE.  THE NETHE'TH IS THE ETHENE NUMBER, AND
C	IS ONE IF THE GLYCOLALDEHYDE YIELD IS NE 0, AND ZERO OTHERWISE.
C
	LOGICAL VARYT
C
C	OPTION TO INPUT K'S IN PPM-MIN UNITS FOR 300K.
C
	RKPPM=.FALSE.
C
C	INITIALIZE TEMPERATURE-DEPENDENT VARIABLES
C
        CTEMP=4.40373E+17/TEMPR
        RTEMP=0.0019872*TEMPR
	BTEMP=TEMPR/300.0
	FIRST=.TRUE.
	VARYT=(THIGH.NE.0.0.AND.TLOW.NE.0.0)
C
C	FIRST 2 PARMS RESERVED FOR KOH AT TLOW AND THIGH, RESPECTIVELY
C
	IF (VARYT) THEN
		RTEMP1=0.0019872*TLOW
		RTEMP2=0.0019872*THIGH
	        CTEMP1=4.40373E+17/TLOW
	        CTEMP2=4.40373E+17/THIGH
		BTEMP1=TLOW/300.0
		BTEMP2=THIGH/300.0
		IF (NAAPRM.EQ.0) THEN
			NAAPRM=2
			AAPNAM(1)='*1'
			AAPNAM(2)='*2'
			AAPRKI(1)=.TRUE.
			AAPRKI(2)=.TRUE.
		ENDIF
	ENDIF		
C
C	MERGE THE 'OLEFIN' PARMS WITH THE ONES ALREADY ON LIST
C	(IF ANY).  LAST 6 ARE FOR THIGH, TLOW K'S, SO MERGE THEM ONLY
C	IF USED.
C
	NOLD=NAAPRM
	DO 100 I=1,NOLEPM
	IF (OLEPNM(I)(1:1).EQ.'*'.AND.(.NOT.VARYT)) THEN
		PRMLOC(I)=0
		GOTO 100
	ENDIF
	IF (NOLD.GT.0) THEN
		DO 102 J=1,NOLD
		IF (AAPNAM(J).EQ.OLEPNM(I)) THEN
			PRMLOC(I)=J
			GOTO 100
		ENDIF
  102		CONTINUE
	ENDIF
C
C	ADD NEW PARM, AND SET ITS VALUE TO ZERO FOR MODEL
C	SPECIES ALREADY ON LIST
C
	IF (NAAPRM.EQ.MXAAPM) THEN
		WRITE (ICRT,*) 'INCREASE MXAAPM IN LUMPSPEC'
		CALL EXIT (2)
	ENDIF
	NAAPRM=NAAPRM+1
	AAPNAM(NAAPRM)=OLEPNM(I)
	AAPRKI(NAAPRM)=I.GE.NKO3
	PRMLOC(I)=NAAPRM
C
	IF (NAA.GT.0) THEN
		DO 104 J=1,NAA
  104		AAPARM(NAAPRM,J)=0.0
	ENDIF
  100	CONTINUE
C
C
C       READ OLEFIN NAMES, #C'S, SUBSTITUENT TYPES
C               (#C'S NOT USED)
C
C
 5200	READ (FUNIT,'(A80)',END=5290) INLIN
	IF (INLIN(1:1).EQ.'!') GOTO 5200
	IF (INLIN(1:1).EQ.' ') GOTO 5200
	IF (INLIN(1:1).EQ.'*') THEN
		IF (INLIN(2:4).EQ.'PPM') THEN
			RKPPM=.TRUE.
		ELSEIF (INLIN(2:6).EQ.'NOPPM') THEN
			RKPPM=.FALSE.
		ELSE
			WRITE (ICRT,*) 'Unrecognized option = ',
     &			 INLIN(1:LNBLNK(INLIN))
			GOTO 5282
		ENDIF
		GOTO 5200
	ENDIF
	NAA=NAA+1
	IF (NAA.GT.MAXAA) THEN
		WRITE (ICRT,*) 'INCREASE MAXAA IN LUMPSPEC'
		CALL EXIT (2)
	ENDIF
	READ (INLIN,'(A8,11X,3I3,G12.0)',ERR=5282) AANAM(NAA),SUBIND,
     &	 IND,OLENT
C
C	IF IND IS NEGATIVE, THEN "OLENT" READ IN IS ACTUALLY
C	GLYCOLALDEHYDE YIELD, AND NITRATE YIELD IS ZERO
C
	IF (IND.LT.0) THEN
		OLEGL=OLENT
		OLENT=0.0
		ETHENE=1.0
	ELSE
		OLEGL=0.0
		ETHENE=0.0
	ENDIF
C
C	INITIALIZE PARMS TO ZERO
C
	DO 5204 I=1,NAAPRM
 5204	AAPARM(I,NAA)=0.0
C
C	IF IND IS 1 OR 3, SAME KINETIC PARMS AS LAST OLEFIN
C       I4=1,4 FOR OH,O3,NO3,O RESPECTIVELY.  OTHERWISE READ
C	THEM FROM FILE, AND CALCULATE K'S.  PUT NON-OH K'S IN
C	APPROPRIATE LOCATION IN MECHANISTIC PARM ARRAY.
C
	IF (IND.EQ.1.OR.IND.EQ.3) THEN
		IF (FIRST) GOTO 5280
		AAKOH(NAA)=AAKOH(NAA-1)
		IF (VARYT) THEN
			AAPARM(1,NAA)=AAPARM(1,NAA-1)
			AAPARM(2,NAA)=AAPARM(2,NAA-1)
		ENDIF
		DO 5203 I=NKO3,NOLEPM
		IF (PRMLOC(I).NE.0) AAPARM(PRMLOC(I),NAA)=
     &		 AAPARM(PRMLOC(I),NAA-1)
 5203		CONTINUE
	ELSE
		FIRST=.FALSE.
 5209		READ (FUNIT,'(A80)',END=5290) INLIN
		IF (INLIN(1:1).EQ.'!') GOTO 5209
		CALL PARSE0 (3,INLIN,80)
C	      - IF THERE IS AN ERROR READING EA OR B, IT IS ASSUMED
C	      - THEY ARE ZERO, AND THE ERROR IS DUE TO A COMMENT.
		CALL PARSER (1,A,ERRIND,INLIN)
		IF (ERRIND) GOTO 5282
		CALL PARSR2 (2,EA,0.0,ERRIND,INLIN)
		IF (ERRIND) THEN
			EA=0.0
			B=0.0
		ELSE
			CALL PARSR2 (3,B,0.0,ERRIND,INLIN)
			IF (ERRIND) B=0.0
		ENDIF
		IF (RKPPM) THEN
			A=A*6.8125E-16
			B=B+1.0
		ENDIF
		AAKOH(NAA)=CTEMP*A*(BTEMP**B)*EXP(-EA/RTEMP)
		IF (VARYT) THEN
			AAPARM(1,NAA)=CTEMP1*A*(BTEMP1**B)*EXP
     &			 (-EA/RTEMP1)
			AAPARM(2,NAA)=CTEMP2*A*(BTEMP2**B)*EXP
     &			 (-EA/RTEMP2)
		ENDIF
		DO 5210 I=NKO3,NKO3+6,3
 5211		READ (FUNIT,'(A80)',END=5290) INLIN
		IF (INLIN(1:1).EQ.'!') GOTO 5211
		CALL PARSE0 (3,INLIN,80)
		CALL PARSER (1,A,ERRIND,INLIN)
		IF (ERRIND) GOTO 5282
		CALL PARSR2 (2,EA,0.0,ERRIND,INLIN)
		IF (ERRIND) THEN
			EA=0.0
			B=0.0
		ELSE
			CALL PARSR2 (3,B,0.0,ERRIND,INLIN)
			IF (ERRIND) B=0.0
		ENDIF
		IF (RKPPM) THEN
			A=A*6.8125E-16
			B=B+1.0
		ENDIF
		AAPARM(PRMLOC(I),NAA)=CTEMP*A*(BTEMP**B)*EXP(-EA/RTEMP)
		IF (VARYT) THEN
			AAPARM(PRMLOC(I+1),NAA)=CTEMP1*A*
     &			 (BTEMP1**B)*EXP(-EA/RTEMP1)
			AAPARM(PRMLOC(I+2),NAA)=CTEMP2*A*
     &			 (BTEMP2**B)*EXP(-EA/RTEMP2)
		ENDIF
 5210		CONTINUE
	ENDIF
C
C	UPDATE SUBSTITUENT, NITRATE AND GLYCOLALD. YIELD PARMS
C
	AAPARM(PRMLOC(NNIT),NAA)=OLENT	
	AAPARM(PRMLOC(NGLA),NAA)=OLEGL
	AAPARM(PRMLOC(NETHE),NAA)=ETHENE
C
C
C	IF IND IS 2 OR 3, READ IN MECHANISTIC PARAMETERS EXPLICITLY,
C	AND IGNORE SUBIND'S.  ONLY PARMS WHICH HAVE BEEN DEFINED
C	PREVIOUSLY CAN BE ACCEPTED, BUT THIS WOULD INCLUDE ALL LEGAL
C	OLEFIN PARMS.
C
	IF (IND.EQ.2.OR.IND.EQ.3) THEN
C
 4340   	READ (FUNIT,'(A)',END=5290) INLIN
		IF (INLIN(1:1).EQ.'!') GOTO 4340
	        IF (INLIN(1:1).EQ.' ') GOTO 4399
C
		CALL PARSE0 (2,INLIN,80)
		CALL PARSE1 (1,NAMEIN,I,2,INLIN)
	        DO 4342 I=1,NAAPRM
	        IF (NAMEIN(1:2).EQ.AAPNAM(I)) THEN
			CALL PARSER (2,F,ERRIND,INLIN)
			IF (ERRIND) GOTO 5280
	                AAPARM(I,NAA)=AAPARM(I,NAA)+F
	                GOTO 4340
	        ENDIF
 4342   	CONTINUE
		WRITE (ICRT,4384) INLIN(1:2),AANAM(NAA)
 4384   	FORMAT (' Unrecognized parm = ''',A2,''' for ',A8,
     &           ' in olefin parameter data set.')
		GOTO 5280
C
 4399		CONTINUE
	ELSE
C	
		IF (SUBIND(1).GT.NOLSUB) GOTO 5280
		IF (SUBIND(2).GT.NOLSUB) GOTO 5280
C
		IF (SUBIND(1).EQ.0) THEN
			IF (SUBIND(2).NE.0) 
     &			 AAPARM(PRMLOC(SUBIND(2)),NAA)=1.0
		ELSEIF (SUBIND(2).EQ.0) THEN
			AAPARM(PRMLOC(SUBIND(1)),NAA)=1.0
		ELSEIF (SUBIND(1).EQ.SUBIND(2)) THEN
			AAPARM(PRMLOC(SUBIND(1)),NAA)=2.0
		ELSE
			AAPARM(PRMLOC(SUBIND(1)),NAA)=1.0
			AAPARM(PRMLOC(SUBIND(2)),NAA)=1.0
		ENDIF
	ENDIF
C
C       LOOP BACK TO NEXT OLEFIN
C
	GOTO 5200
C
C	ERROR
C
 5280   WRITE (ICRT,*) 'Bad input in olefin lumping parm file.'
	GOTO 5288
 5282   WRITE (ICRT,*) 'Error reading input in olefin lumping parm file'
     &	 ,'.  Input line is:'
	WRITE (ICRT,*) INLIN
 5288   WRITE (ICRT,*) 'Current, last model compound processed = ',
     &	 AANAM(NAA),', ',AANAM(NAA-1)
        CALL EXIT (2)
C
C
C	DONE
C
 5290   CLOSE (UNIT=FUNIT)
	RETURN
	END
