C	LUMPSPEC.FTN
C
C	SPECIFICATIONS FOR 'LUMPED' HC PROGRAM.  PC VERSION.
C
C
C	TEMPERATURE FOR WHICH K'S AND PARMS ARE CALCULATED.  CTEMP,
C	RTEMP, AND TOV300 ARE TEMPERATURE-DEPENDENT PARMS USED TO
C	CALCULATE K'S
C
	REAL TEMPR,CTEMP,TOV300,RTEMP,THIGH,TLOW
C
C
C	INTEGRATED OH CONCENTRATION USED TO CALCULATE AVERAGES
C
	REAL INTOH
C
C
C	VARIABLES USED TO CONTROL OUTPUT FORMAT
C
C	LPRECH	PREFIX FOR MODEL SPECIES NAMES
C	LPRE	LENGTH OF PREFIX
C	INTFMT	OUTPUT TO BE FORMATTED SO IT CAN BE USED AS
C		INPUT INTO SAPRC INT PROGRAM.
C	SHORT	PREVENTS INTLUMP FROM CONDENSING GROUPS
C	OUTRXN	OUTPUTS PAREMETERS WITH NAMED REACTANTS ONLY
C		(APPLICABLE FOR OZIPR PREPARATION)
C	NAMEOK	ALLOWS GENERATION OF .NAME STATEMENT WHERE APPLICABLE
C	TOPPM	CONVERTS KINETIC DATA FROM CM-MOLEC-SEC TO PPM-MIN UNITS.
C
	CHARACTER*4 LPRECH
	INTEGER LPRE
	LOGICAL INTFMT,SHORT,OUTRXN,NAMEOK,TOPPM
C
C
C	MISC.
C
C	MECUIC	LOCATION OF "INCLUDE" FILES (FROM MODELING.PRM OR .PRM FILE)
C	PRMCNV	PARAMETER CONVERSION PROGRAM, IF USED.
C	SPARE1	SPARE CHARACTER STRINGS
C	SPARE2
C
	CHARACTER*60 MECUIC,PRMCNV,SPARE1,SPARE2
C	
C	------------------------------------------------------------
C	SPECIFICATIONS FOR DETAILED MODEL SPECIES
C	------------------------------------------------------------
C
C	MAXAA	MAXIMUM NO. DETAILED MODEL SPECIES
C	NAA	NO. DETAILED MODEL SPECIES
C	AANAM	SPECIES NAMES
C	AAKOH	OH RATE CONSTANT AT TEMPERATURE TEMPR
C	AAGRP	ID FOR LUMPING GROUP.  ONLY SPECIES WITH SAME AAGRP ID
C		WILL BE LUMPED TOGETHER MUST BE GE 1 AND LE MAXGRP 
C
C	MXAAPM	MAXIMUM NO. MECHANISTIC PARAMETERS PER MODEL SPECIES
C	NAAPRM	NO. MECHANISTIC PARMETERS PER MODEL SPECIES
C	AAPARM	MECHANISTIC PARAMETERS
C	AAPNAM	2- TO 6-CHARACTER CODE NAMES FOR PARAMETERS
C	AAPRKI	LOGICAL VARIABLE WHICH IS TRUE IF PARM IS A RATE
C		CONSTANT 
C	AAPROD	PRODUCT FORMED (APPLICABLE FOR OUTRXN=TRUE ONLY)
C
C
	PARAMETER (MAXAA=1200,MXAAPM=600)
	INTEGER NAAPRM,NAA
C
	LOGICAL AAPRKI(MXAAPM)
	CHARACTER*6 AAPNAM(MXAAPM)
	CHARACTER*8 AAPROD(MXAAPM)
	CHARACTER*8 AANAM(MAXAA)
	INTEGER AAGRP(MAXAA)
	REAL AAKOH(MAXAA),AAPARM(MXAAPM,MAXAA)
C
C	SPECIFICATIONS FOR PRE-SUBSTITUTED SPECIES MODEL SPECIES
C
C	MAXSUB	MAX. NO SUBSTITUTIONS
C	NSUB	TOTAL NO. OF SUBSTITUTIONS.
C	SUBNAM	NAMES TO BE SUBSTITUTED
C	SUBOUT	NAMES REPLACING SUBSTITUTED NAMES
C	SUBFAC	FACTOR TO CHANGE LEVEL WHEN SUBSTITUTING
C
	PARAMETER (MAXSUB=1000)
	INTEGER NSUB
	CHARACTER*8 SUBNAM(MAXSUB),SUBOUT(MAXSUB)
	REAL SUBFAC(MAXSUB)
C	SPECIFICATIONS FOR "MIXTURES" (1 -> MANY SUBSTITUTIONS)
C
C	MAXMIX	MAX NUMBER OF MIXTURES
C	MAXMXS	MAX NUMBER OF COMPONENTS IN ALL MIXTURES
C	NMIXS	NUMBER OF MIXTURES
C	MIXI2	INDEX FOR NEXT AVAILABLE COMPONENT IN LIST
C	MIXNAM	NAME SUBSTITUTED BY MIXTURE
C	MIXI1	INDEX FOR FIRST COMPONENT OF A MIXTURE
C	NMIXI	NUMBER OF COMPONENTS IN A MIXTURE
C	MIXMOL	TOTAL NUMBER OF MOLES OF COMPONENTS IN MIXTURE
C	MIXCMP	COMPONENT NAME
C	MIXFAC	RELATIVE MOLAR AMOUNT OF COMPONENT
C
	PARAMETER (MAXMIX=300,MAXMXS=2400)
	INTEGER NMIXS,MIXI2,MIXI1(MAXMIX),NMIXI(MAXMIX)
	CHARACTER*8 MIXNAM(MAXMIX),MIXCMP(MAXMXS)
	REAL MIXFAC(MAXMXS),MIXMOL(MAXMIX)
C
C
C	SPECIFICATIONS FOR EXPLICIT MODEL SPECIES.  THESE ARE INPUT USING
C	THE "SPECIES" COMMAND IN THE LUMPING CONTROL FILES.  ALL EMITTED
C	SPECIES WHICH ARE REPRESENTED EXPLICITLY IN THE MECHANISM, EXCEPT
C	FOR "LUMPED GROUPS" (WHICH ARE INPUT USING THE "GROUP" COMMAND),
C	SHOULD BE INCLUDED HERE, WITH THEIR NUMBER OF CARBONS AND MOLECULAR
C	WEIGHT SPECIFIED.  (NOTE THAT IF A DETAILED MODEL SPECIES NAME
C	MATCHES THAT OF AN "EXPLICIT MODEL SPECIES" SPECIFIED HERE, THEN
C	THE DETAILED MODEL SPECIES IS ASSUMED TO BE REPRESENTED EXPLICITLY,
C	AND IT IS NOT INCLUDED IN A LUMPED GROUP.  NOTE ALSO THAT IF THE
C	MODEL RECOGNIZES THE SPECIAL SPECIES "NROG" AND/OR "LOST", THESE
C	NAMES NEED TO BE INCLUDED IN THE "SPECIES" INPUT, THOUGH THEIR
C	INPUT NUMBER OF CARBONS AND MOLECULAR WEIGHTS WILL BE OVER-WRITTEN
C	TO GIVE THE VALUES APPROPRIATE FOR THE EMISSIONS PROFILE BEING
C	USED.)
C
C	MMODSP	MAX NO EXPLICIT MODEL SPECIES
C	NMODSP	NO. EXPLICIT MODEL SPECIES
C	MODSP	NAMES OF EXPLICIT MODEL SPECIES
C	MODNC	NO. CARBONS
C	MODMW	MOLECULAR WT.
C	MODKOH	OH RATE CONSTANT FOR EXPLICIT SPECIES (ONLY USED TO
C		UPDATE KOH'S IN DMS LISTINGS.   NOT USED FOR LUMPING)
C
	PARAMETER (MMODSP=1000)
	INTEGER NMODSP,MODNC(MMODSP)
	CHARACTER*8 MODSP(MMODSP)
	REAL MODMW(MMODSP),MODKOH(MMODSP)
C
C
C	-------------------------------------------
C	SPECIFICATIONS FOR LUMPED GROUPS
C	-------------------------------------------
C
C	LUMPED PARAMETER GROUPS:
C
C	MAXGRP	MAXIMUM NO. "LUMPED PARAMETER" GROUPS
C	NGRP		NO. OF SUCH GROUPS
C	KOHMIN	MINIMUM OH RATE CONSTANT FOR MEMBERS OF THE GROUP
C	GRPTYP	TYPE ID FOR THIS GROUP, USED TO DETERMINE WHICH SETS
C			OF SPECIES LUMPED IN IT 
C	GRPNAM	NAME OF LUMPED GROUP
C	GRPPNM	PARM NAME PREFIX FOR GROUP (THE ABOVE TWO MUST
C			CORRESPOND WITH NAMES AND PARMS USED IN MODEL) 
C	TOTGRP	TOTAL AMOUNT OF MOLES IN THIS GROUP
C	RCTGRP 	TOTAL MOLES REACTED FOR GROUP, NEEDED FOR AVERAGING
C			PURPOSES.
C	RKGRP 	WEIGHTED OH RATE CONST FOR GROUP
C	DRKGRP	DEFAULT OH RATE CONSTANT FOR GROUP (USED ONLY IF
C			WEIGHED AVERAGING DONE FOR THIS GROUP)
C	DAGRP		DEFAULT A FOR GROUP
C       DEAGRP  	DEFAULT EA FOR GROUP
C       DBBRP   	DEFAULT BPRM FOR GROUP
C	PRMGRP	WEIGHTED PARMS FOR GROUP
C	NCGRP		NUMBER OF CARBONS IN THIS GROUP
C	NCRGRP	NUMBER OF CARBONS IN THE 'REACTING' PORTION OF THIS
C			GROUP 
C	MASGRP	TOTAL MASS IN THIS GROUP (MW*MOLES)
C	MSRGRP	TOTAL MASS IN THE 'REACTING' PORTION OF THIS GROUP 
C	GRPIND	INDICATOR FOR AVERAGING METHOD:
C			0 = SIMPLE AVERAGE, 1 = USE INTOH, 2 = WEIGH BY KOH. 
C			3 = USE INTOH FOR KOH < DRKGRP, SIMPLE FOR => KOH.
C
	PARAMETER (MAXGRP=16)
	INTEGER NGRP,GRPTYP(MAXGRP),GRPIND(MAXGRP)
	CHARACTER*4 GRPNAM(MAXGRP)
	CHARACTER*2 GRPPNM(MAXGRP)
        REAL TOTGRP(MAXGRP),RCTGRP(MAXGRP),RKGRP(MAXGRP),
     &	 DRKGRP(MAXGRP),DAGRP(MAXGRP),DEAGRP(MAXGRP),DBGRP(MAXGRP),
     &	 KOHMIN(MAXGRP),PRMGRP(MXAAPM,MAXGRP),NCGRP(MAXGRP),
     &	 NCRGRP(MAXGRP),MASGRP(MAXGRP),MSRGRP(MAXGRP)
C
C
C	"NON-LUMPED-PARAMETER" GROUPS:
C
C	MAXNLS	MAXINUM NUMBER OF SUCH GROUPS
C	NNLS	NO OF GROUPS
C	NLSNAM	NAME OF GROUP
C	NLSLVL	NO. MOLES IN GROUP
C	NLSNC	NO. CARBONS
C	NLSMAS	MASS IN GROUP
C	NROG	NO. MOLES CARBON IN SPECIAL "UNREACTIVE" GROUP
C
	PARAMETER (MAXNLS=700)
	INTEGER NNLS
	CHARACTER*8 NLSNAM(MAXNLS)
	REAL NLSLVL(MAXNLS),NLSNC(MAXNLS),NLSMAS(MAXNLS),NROG
C
C
C	FOLLOWING USED BY LMPSUB
C
C	MAXDMS	MAX. NO DETAILED MODEL SPECIES
C
	PARAMETER (MAXDMS=540)
C
C	------------------------------------------------------------
C	COMMON BLOCKS FOR LUMPING DATA.
C	------------------------------------------------------------
C
	LOGICAL*4 NOLPC
C
	COMMON /LMPDAT/ NOLPC,TEMPR,NGRP,NAA,NSUB,NAAPRM,AAKOH,AAPARM,
     &	 AAGRP,AAPRKI,SUBFAC,NMODSP,MODNC,NNLS,NCRGRP,INTOH,MODMW,LPRE,
     &	 INTFMT,SHORT,KOHMIN,TOTGRP,RKGRP,PRMGRP,GRPTYP,NCGRP,THIGH,
     &	 TLOW,GRPIND,MASGRP,MSRGRP,NROG,RTEMP,CTEMP,TOV300,
     &	 NLSLVL,NLSNC,NLSMAS,RCTGRP,DRKGRP,DAGRP,DEAGRP,DBGRP,MODKOH,
     &	 ATM,NMIXS,MIXI2,MIXI1,NMIXI,MIXFAC,MIXMOL,OUTRXN,NAMEOK,TOPPM
	COMMON /LMPCHR/ AANAM,SUBNAM,AAPNAM,SUBOUT,MODSP,LPRECH,
     &	 GRPNAM,GRPPNM,NLSNAM,MECUIC,PRMCNV,SPARE1,SPARE2,AAPROD,
     &	 MIXNAM,MIXCMP
C	
C	------------------------------------------------------------
C	STANDARD FILE UNIT SPECIFICATIONS
C	------------------------------------------------------------
C
	INTEGER ICRT,IKEY,UNIT1,UNIT2,UNIT3,UNIT4
	PARAMETER (ICRT=6,IKEY=5)
	PARAMETER (UNIT1=1,UNIT2=2,UNIT3=3,UNIT4=4)
C
C	
C	------------------------------------------------------------
C	INPUT/OUTPUT BUFFERS (USED TO COMMUNICATE WITH INBUF)
C	------------------------------------------------------------
C
	LOGICAL    SHOW, NOKEY
	INTEGER    IN, IOLEN, IORET
	CHARACTER    IOB160*160, IOBF16*16
C 
	COMMON /IOBUF/ IN,IOLEN,IORET,MAXUNT,NOKEY,SHOW
	COMMON /IOBFCH/ IOBF16,IOB160
C
	SAVE IOBUF,IOBFCH
C
