	SUBROUTINE EXPLSP (LNAM,IND,FAC,EXPKOH,LEXPK,TMPU)
C
C	DETERMINES IF SPECIES IS EXPLICIT, AND IF SO, CALCULATES ITS
C	FRACTION REACTED GIVEN THE FR-KOH INPUT.
C
C	ARGUMENTS:
C		LNAM	SPECIES NAME (8-CHAR) (INPUT)
C		IND	STATUS (OUTPUT):  1 = EXPLICIT, 0 = NOT EXPLICIT,
C					 -1 = ERROR
C		FAC	FRACTION REACTED (OUTPUT).  ZERO IF NOT EXPLICIT
C			(OR EFFECTIVE NO. CARBONS IF LEXPK <0.)
C		EXPKOH	FILE NAME FOR EXPLICIT-KOH DATA
C		LEXPK	LENGTH OF ABOVE.  IF NEGATIVE, JUST DETERMINES
C			WHETHER LNAM IS EXPLICIT, AND RETURNS FAC=NO. C'S.
C		TMPU	UNIT TO READ EXPLICIT-KOH DATA.
C
	CHARACTER LNAM*8,EXPKOH*40,INLIN*80
	INTEGER IND,LEXPK,TMPU
	REAL FAC
C
	PARAMETER (MAXEXP=200)
	CHARACTER*8 EXPNAM(MAXEXP)
	REAL KOH(MAXEXP),EXPCOR(MAXEXP),EXPNC(MAXEXP)
	COMMON /KOHDAT/ NEXP,KOH,EXPCOR,EXPNC
	COMMON /KOHCHR/ EXPNAM
	LOGICAL NOEXP
	DATA NOEXP/.TRUE./
C
C
C	FIRST READ EXPLICIT KOH DATA INTO MEMORY, IF NOT DONE SO
C	PREVIOUSLY
C
	IF (NOEXP) THEN
C
		OPEN (UNIT=TMPU,FILE=EXPKOH,STATUS='OLD',ERR=800)
		NEXP=0
   34		READ (TMPU,'(A)',END=36) INLIN
		IF (INLIN(1:4).EQ.'END ') THEN
			GOTO 36
		ELSEIF ((INLIN(1:1).EQ.' ').OR.INLIN(1:1).EQ.'!') THEN
			GOTO 34
		ENDIF
		NEXP=NEXP+1
		IF (NEXP.GT.MAXEXP) THEN
			WRITE (6,*) 'INCREASE MAXEXP IN RCSUBS.FOR'
			WRITE (6,*) 'Too much data in ',
     &			 EXPKOH(1:IABS(LEXPK))
			IND=-1
			FAC=0.0
			RETURN
		ENDIF
		READ (INLIN,'(A8,E10.3,F8.2,F8.0)',ERR=349)
     &		 EXPNAM(NEXP),KOH(NEXP),EXPCOR(NEXP),EXPNC(NEXP)
		GOTO 34
  349		NEXP=NEXP-1
		GOTO 34
   36		CLOSE (UNIT=TMPU)
C
		NOEXP=.FALSE.
C
	ENDIF
C
C
C	SEE IF THIS IS EXPLICIT MODEL SPECIES.  IF SO, CALCULATE
C	FRACTION REACTED
C
	FAC=0.0
	DO 40 I=1,NEXP
	IF (LNAM.EQ.EXPNAM(I)) THEN
		IND=1
		IF (LEXPK.LT.0) THEN
			FAC=EXPNC(I)
			IF (FAC.EQ.0.0) FAC=1.0
			RETURN
		ELSEIF (EXPCOR(I).LT.0) THEN
			FAC=1.0
		ELSEIF (EXPCOR(I).GT.0) THEN
			FAC=AMIN1(1.0,EXPCOR(I)*GETFR(KOH(I)))
		ELSE
			FAC=GETFR(KOH(I))
		ENDIF
		RETURN
	ENDIF
   40	CONTINUE
C
C	NOT FOUND
C
	IND=0
	RETURN
C
C	ERROR
C
  800	WRITE (6,*) 'EXPLICIT-KOH file = ',EXPKOH(1:IABS(LEXPK)),
     &	 ' does not exist.'
	FAC=0.0
	IND=-1
	RETURN
C
	END
C
C
	SUBROUTINE ADDFR (RKOH,FRCTD)
C
C	ADDS FRACTION REACTED INPUT.  CALCULATES INTOH FOR IT.
C
	PARAMETER (MAXFR=12)
	REAL KOH(MAXFR),INTOH(MAXFR)
	COMMON /FRDAT/ KOH,INTOH,NFR
C
	IF (NFR.NE.0) THEN
		DO 10 I=1,NFR
		IF (KOH(I).EQ.RKOH) THEN
			IFR=I
			GOTO 20
		ENDIF
   10		CONTINUE
	ENDIF
	IF (NFR.EQ.MAXFR) STOP 'TOO MUCH FR-KOH INPUT'
	NFR=NFR+1
	KOH(NFR)=RKOH
	IFR=NFR
   20	IF (FRCTD.GE.1.0) THEN
		INTOH(IFR)=-1.0
	ELSE
		INTOH(IFR)=-ALOG(1.0-FRCTD)/RKOH
	ENDIF
	RETURN
	END
C
	FUNCTION GETFR (RKOH)
C
C	CALCULATES FRACTION REACTED GIVEN KOH AND FR-KOH DATA
C	IN COMMON.
C
	PARAMETER (MAXFR=12)
	REAL KOH(MAXFR),INTOH(MAXFR),RKOH,IOH
	COMMON /FRDAT/ KOH,INTOH,NFR
C
	IF (NFR.EQ.0) STOP 'GETFR CALLED WITH NFR=0'
C
C	FIND VALUES JUST ABOVE AND JUST BELOW RKOH
C
	IMIN=0
	RK1=0.0
	IMAX=0
	RK2=1.0E+20
	DO 10 I=1,NFR
	IF (RKOH.GT.KOH(I)) THEN
		IF (KOH(I).GT.RK1) THEN
			RK1=KOH(I)
			IMIN=I
		ENDIF
	ELSEIF (RKOH.LT.KOH(I)) THEN
		IF (KOH(I).LT.RK2) THEN
			RK2=KOH(I)
			IMAX=I
		ENDIF
	ELSE
		IOH=INTOH(I)
		GOTO 20
	ENDIF
   10	CONTINUE
	IF (IMIN.EQ.0) THEN
		IOH=INTOH(IMAX)
	ELSEIF (IMAX.EQ.0) THEN
		IOH=INTOH(IMIN)
	ELSE
	    IF (INTOH(IMIN).LT.0.0.OR.INTOH(IMAX).LT.0.0) THEN
		IOH=-1.0
	    ELSE
		IOH=((INTOH(IMIN)*(KOH(IMAX)-RKOH))
     &		 +(INTOH(IMAX)*(RKOH-KOH(IMIN))))
     &		 /(KOH(IMAX)-KOH(IMIN))
	    ENDIF
	ENDIF
C
   20	IF (IOH.LT.0.0) THEN
		GETFR=1.0
	ELSE
		GETFR=1.0-EXP(-IOH*RKOH)
	ENDIF
	RETURN
	END
C
