	PROGRAM RCTAVG
C
C	CALCULATES AVERAGE KINETIC AND INCREMENTAL REACTIVITIES FOR A
C	SET OF SCENARIOS, AND CREATES A ".RCT" FILE FOR THE GROUP.
C		USED FOR MAXRCT AND MAXO3 SCALES (1998+ VERSIONS)
C
C	READS DMS LIST AND MOLECULAR WEIGHTS FROM DMS.PRM (DMS= INPUT IN
C	MODELING.PRM)
C
C	READS REACTIVITIES FROM .RCT FILES (RCT= INPUT IN MODELING.PRM)
C	.RCT FILES MUST BE IN FORMAT CREATED BY DMSRCT (VERS.2)
C
C	USEAGE:  RCTAVG inputfile rctfile
C
C	inputfile = FILE CONTAINING LIST OF SCENARIOS TO READ.  MUST
C		    BE .RCT FILE FOR SCENARIO.
C	rctvile   = NAME OF .RCT FIILE CREATED.
C
C	USES ONLY DMS SPECIES LISTED IN ALL FILES.
C
C	DMS ASSIGNMENT DATA
C
	INCLUDE 'DMSSPC.FOR'
	CHARACTER DMSIND(MAXDMS)*1
C
C	SCENARIO AND REACTIVITY DATA
C
	PARAMETER (MAXSCN=50)
	INTEGER NSCN
	REAL DMSKR(MAXDMS,MAXSCN),DMSIR(MAXDMS,MAXSCN)
	CHARACTER SCNID(MAXSCN)*8
C
	REAL NODATA
	PARAMETER (NODATA=-9.99E+9)
	CHARACTER INLIN*80,INFILE*40,OUTFIL*40,FILNAM*60
C
C
	CALL GETARG (1,INFILE)
	IF (INFILE(1:1).EQ.' '.OR.OUTFIL(1:1).EQ.' ') THEN
		WRITE (6,*) 'USEAGE:  RCTAVG inputfile rctfile'
		CALL EXIT (0)
	ENDIF
	LINFIL=LNBLNK(INFILE)
	CALL GETARG (2,OUTFIL)
	LOUTFL=LNBLNK(OUTFIL)
C
C
C	GET RCT FILE UICS FROM MODELING.PRM
C
	OPEN (UNIT=1,FILE='MODELING.PRM',STATUS='UNKNOWN')
C
	RCTUIC=' '
	LRCTUC=0
  221	READ (1,1,END=222) INLIN
	IF (INLIN(1:4).EQ.'RCT=') THEN
		RCTUIC=INLIN(5:)
		LRCTUC=LNBLNK(RCTUIC)
	ENDIF
	GOTO 221
  222	CLOSE (UNIT=1)
C
C
C	GET DMS DATA
C
	CALL LDDMS (I)
	IF (I.NE.0) GOTO 800
C
C	INITIALIZE DMSIND
C
	DO 223 I=1,NDMS
  223	DMSIND(I)=' '
C
C
C	OPEN INPUT AND OUTPUT FILES.  
C
	OPEN (UNIT=1,FILE=INFILE(1:LINFIL),STATUS='OLD',ERR=810)
C
	OUTFIL(LOUTFL+1:LOUTFL+4)='.RCT'
	LOUTFL=LOUTFL+4
	OPEN (UNIT=2,FILE=OUTFIL(1:LOUTFL),STATUS='UNKNOWN')
C
	NSCN=0
C
C	READ NEXT SCENARIO
C
  100	READ (1,1,END=200) INLIN
    1	FORMAT (A)
	IF (INLIN(1:1).EQ.'!'.OR.INLIN(1:1).EQ.' ') GOTO 100
	NSCN=NSCN+1
	SCNID(NSCN)=INLIN(1:8)
	IF (NSCN.GT.MAXSCN) STOP 'TOO MANY SCENARIOS'
	WRITE (6,*) 'Reading scenario = ',INLIN(1:LNBLNK(INLIN))
C
C	INITILIZE KR, MR TO UNDEFINED.
C
 	DO 110 I=1,NDMS
  110	DMSKR(I,NSCN)=NODATA
C
C
C	OPEN .RCT FILE
C
	L=LNBLNK(SCNID(NSCN))
	IF (LRCTUC.EQ.0) THEN
		FILNAM=SCNID(NSCN)(1:L)
	ELSE
		FILNAM=RCTUIC(1:LRCTUC)
		FILNAM(LRCTUC+1:LRCTUC+L)=SCNID(NSCN)(1:L)
		L=LRCTUC+L
	ENDIF
	FILNAM(L+1:L+4)='.RCT'
	OPEN (UNIT=4,FILE=FILNAM,STATUS='OLD',ERR=820)
C
C	READ TO START-OF-DATA MARKER FOR EXPECTED .RCT FILE FORMAT.
C
  120	READ (4,1,END=830) INLIN
	IF (INLIN(1:1).NE.',') GOTO 120
C
C	READ DATA
C
  130	READ (4,1,END=140) INLIN
	IF (INLIN(1:1).EQ.'!'.OR.INLIN(1:1).EQ.' ') GOTO 130
C
	DO 132 I=1,NDMS
	IF (INLIN(1:8).EQ.DMSNAM(I)) THEN
		READ (INLIN,'(8X,F10.4,9X,E10.2)',ERR=835) DMSKR(I,NSCN),
     &		 DMSIR(I,NSCN)
C	      -	DMSIND SET IF MR ESTIMATED USING "PURE MECH" SPECIES
		IF ((INLIN(55:55).EQ.'.'.AND.INLIN(60:63).EQ.'    ').OR.
     &		 INLIN(74:74).EQ.'*') DMSIND(I)='*'
	ENDIF
  132	CONTINUE
	GOTO 130
C
C	DONE READING DATA.  LOOP BACK FOR NEXT SCENARIO.
C
  140	CLOSE (UNIT=4)
	GOTO 100
C
C
C	ALL SCENARIO DATA READ
C
  200	CLOSE (UNIT=1)
	WRITE (6,*) 'No. scenarios =',NSCN
	IF (NSCN.LT.2) THEN
		WRITE (6,*) 'Too few scenarios to aggregate.'
		GOTO 890
	ENDIF
C
C	WRITE HEADER FOR DATA TO OUTPUT FILE
C
	WRITE (2,201) OUTFIL(1:LOUTFL),INFILE(1:LINFIL),NSCN,
     &	 (SCNID(I),I=1,NSCN)
  201	FORMAT ('File = ',A/
     &   /'Reactivities computed by averaging kinetic and ',
     &    'incremental reactivities.'
     &   /'Scenario listing file = ',A,'.',I5,' Scenarios used:'/
     &   /(6(3X,A8)))
	WRITE (2,202)
  202	FORMAT (/'DMSname     -Avg.-     Calc     -- Averaged --',
     &    '       ----- Standard Dev. ------'
     &   /'              KR       MR/C     IR/C      IR/G       -',
     &    '--- KR ----   -- IR/C ---'/',')
C
C
C	LOOP THROUGH ALL DMS.  SKIP THOSE WITH UNDEFINED RCT.
C	OUTPUT AVERAGES.
C
	NTOT=0
C
	DO 310 I=1,NDMS
	N=0
	AVGKR=0.0
	SDEVKR=0.0
	AVGIR=0.0
	SDEVIR=0.0
C
	DO 320 J=1,NSCN
	IF (DMSKR(I,J).EQ.NODATA) GOTO 310
	N=N+1
	AVGKR=AVGKR+DMSKR(I,J)
	SDEVKR=SDEVKR+(DMSKR(I,J)**2)
	AVGIR=AVGIR+DMSIR(I,J)
	SDEVIR=SDEVIR+(DMSIR(I,J)**2)
  320	CONTINUE
C
C	COMPUTE AVG, SDEV AND OUTPUT
C
	XN=FLOAT(N)
	AVGKR=AVGKR/XN
	AVGIR=AVGIR/XN
	IF (N.EQ.1) THEN
		SDEVKR=0.0
		SDEVIR=0.0
	ELSE
		X=XN-1.0
		SDEVKR=SQRT(ABS((SDEVKR-(XN*AVGKR*AVGKR))/X))
		SDEVIR=SQRT(ABS((SDEVIR-(XN*AVGIR*AVGIR))/X))
	ENDIF
	X=ABS(SDEVKR)
	IF (AVGKR.EQ.0.0.OR.X.GT.0.98*AVGKR) THEN
		INLIN(2:6)='(---)'
	ELSE
		WRITE (INLIN(1:4),'(F4.2)') X/AVGKR
		IF (INLIN(3:3).EQ.'0') INLIN(3:3)=' '
		INLIN(2:2)='('
		INLIN(5:6)='%)'
	ENDIF
	X=ABS(SDEVIR)
	IF (AVGIR.EQ.0.0.OR.X.GT.0.98*AVGIR) THEN
		INLIN(8:12)='(---)'
	ELSE
		WRITE (INLIN(7:10),'(F4.2)') X/AVGIR
		IF (INLIN(9:9).EQ.'0') INLIN(9:9)=' '
		INLIN(8:8)='('
		INLIN(11:12)='%)'
	ENDIF
C
	IF (AVGKR.NE.0.0) THEN
		AVGMR=AVGIR/AVGKR
	ELSE
		AVGMR=0.0
	ENDIF
	WRITE (2,'(A8,F10.4,F9.3,2F10.4,F12.4,1X,A5,F8.4,A1,A5)') 
     &	 DMSNAM(I),AVGKR,AVGMR,AVGIR,48.0*DMSNC(I)*AVGIR/DMSMW(I),
     &	 SDEVKR,INLIN(2:6),SDEVIR,DMSIND(I),INLIN(8:12)
	NTOT=NTOT+1
C
  310	CONTINUE
C
C
C	DONE
C
	CLOSE (UNIT=2)
	WRITE (6,*) 'File = ',OUTFIL(1:LOUTFL),' written.'
	WRITE (6,*) 'No. DMS in file =',NTOT
	CALL EXIT (0)
C
C
C	ERRORS
C
  800	WRITE (6,*) 'Aborted.'
	GOTO 899
  810	WRITE (6,*) 'File = ',INFILE(1:LINFIL),' does not exist.'
	GOTO 890
  820	WRITE (6,*) 'File = ',FILNAM(1:LNBLNK(FILNAM)),' does not exist.'
	GOTO 890
  830	WRITE (6,*) 'File = ',FILNAM(1:LNBLNK(FILNAM)),
     &	 ' has no data or wrong format.'
	GOTO 888
  835	WRITE (6,*) 'Error reading KR and MR data from file = ',
     &	 FILNAM(1:LNBLNK(FILNAM)),'.'
C
  888	CLOSE (UNIT=4)
C
  890	CLOSE (UNIT=2,STATUS='DELETE')
  899	CALL EXIT (0)
	END
