	PROGRAM REACTCAL
C
C	DOES MODEL CALCULATION FOR REACTIVITY RUNS.  THIS VERSION
C	FOR ONLY ONE CALC AT A TIME.
C
C	MODIFICATIONS AFTER EPA-90 REACTIVITY REPORT:
C
C	8/2/91	
C	- NOW DEFAULT AMOUNT ADDED IS SUCH THAT CORRECTION FACTOR
C	  USED TO DETERMINE ESTIMATED AMOUNT REACTED.
C	- SCENARIO.PRM ONLY READ FOR BASE CASE CALCS.  PARMS FOR
C	  TEST CALCULATIONS READ FROM .BAS FILE.
C	- NO CARBONS IN TEST SPECIES READ FROM CODE RECORD IN TESTHC.INS
C	  TO FIGURE AMOUNT ADDED BASED ON ESTIMATED *CARBONS* REACTING.
C
C	** 4/19/01:  AMOUNT ADDED NOW BASED ON ESTIMATED *MOLES* REACTING, NOT
C		MOLES CARBON.  NUMBER OF CARBONS (TSTNC) STILL INPUT, BUT
C		IS NOT USED BY DEFAULT.
C		TO RE-ENABLE, SET USENC TO .TRUE., AND RE-COMPILE (CURRENTLY
C		NOT AN INPUT OPTION)
C
C	THIS VERSION READS SCENARIO PARMS FROM SCENARIO.PRM
C	(ALTERNATE SCENARIO.PRM FILE CAN BE NAMED AS "SCENPARM="
C	INPUT IN MODELING.PRM)
C
C	FOR F77L ONLY.
C
C	PARAMETERS ON COMMAND LINE:
C
C	P1	SCENARIO ID.  SCENARIO MUST BE DEFINED IN SCENARIO.PRM
C
C	P2	TEST MIX ID. OR "BASE".  IF A TEST MIX, MUST BE DEFINED IN
C		DATA SET NAMED BY "BASEHC=" IN MODELING.PRM
C	    OR
C		"+".  JUST PRODUCES .INT FILE FOR PURPOSE OF DETERMINING
C		O3MAX.  BASE CALC MUST HAVE ALREADY BEEN DONE.  VARIABLE
C		.INT FILE HAS "@REACTCAL.IN" RECORD JUST BEFORE FIRST .INT
C		OR .SETDEF RECORD.
C	    OR
C		"NOX-???" OR "NOx-???", TO USE ADJUSTED NOX FOR SCENARIO
C		SPECIFIED IN P3
C		"ROG-???", TO USE ADJUSTED ROG FOR SCENARIO SPECIFIED IN P3
C		ABOVE FOR BASE CASE CALCULATIONS.
C		"N=?.?? OR "C=?.??" TO USE SPECIFIED E.NOX OR E.HC,
C		WITH OTHER INPUTS TAKEN FROM SCENARIO SPECIFIED IN P3
C	    OR
C		F=file, TO READ THE TESTHC PARAMETERS FROM A FILE RATHER
C		THAN TESTHC.INS.  THE FILE IS ASSUMED TO HAVE A .GNA
C		FORMAT, WITH "MWT" AND "NC" INPUT.  THE MODEL SPECIES
C		"GEN1", PARAMETER PREFIX "G1" IS USED.  THE MWT AND NC
C		ARE STORED IN THE .CLC FILE.
C
C	P3	ONE OF FOLLOWING OPTIONAL PARAMETERS
C
C		"INTFILE", TO STOP AFTER MAKING INTFILE.
C		"ADDED", TO SPECIFY AMOUNT ADDED
C		"SUBST", TO SPECIFY AMOUNT SUBSTITUTED
C		"NOCHECK", TO SPECIFY THAT REACTIVITY IS TO BE RE-CALCULATED
C		 REGARDLESS OF WHETHER IT IS ALREADY ON .CLC FILE.
C		"SCENLOG", TO LOG SCENARIO CHARACTERISTICS.  OUTPUT GOES TO
C		FILE=REACTCAL.LOG
C		"PRM=prmfile" IF PARAMETER FILE TO BE READ AFTER MODELING.PRM.
C	    OR
C		SCENARIO ID IF "NOX-MIR", ETC. OPTION SPECIFIED.  ALL
C		CONDITIONS, AND MIR/MOR NOX OR VOC TAKEN FROM .BAS FILE
C		FOR THIS SCENARIO.
C
C	P4	AMOUNT ADDED OR SUBSTITUTED, IF "ADDED" OR "SUBST" OPTIONS
C		USED.
C		(FOR "SUBST", SUB OPTION CAN INCLUDED TO GIVE AMOUNT OF
C		 TEST VOC REPLACING EACH MOLE OF BASE ROG.  IF NEGATIVE,
C		 RECRIPROCAL USED.)
C		 
C	P5	"%" IF AMOUNT ADDED OR SUBSTITUTED TO BE GIVEN AS PERCENT
C		OF BASE ROG.
C
C		IF "ADDED" OR "SUBST" OPTION USED, RESULT APPENDED TO
C		'SUBSTDAT.CLC' FILE IN HOME DIRECTORY.
C
C	CREATES MODDOC.IN, TESTHC.IN, BASEHC.IN AS TEMPORARY FILES,
C	AND DELETES THEM WHEN DONE.
C
C	SCENARIO PARAMETERS READ FROM SCENARIO.PRM:
C
C	CODE	 USE
C	-------- ---------------------------------------------------
C	SCNTYPE	 PHYSICAL SCNARIO TYPE.  Scentype.INP USED AS BASIS
C		 FOR .INT FILE.  (.INP FILES READ FROM DIRECTORY
C		 NAMED BY "INP=" INPUT IN MODELING.PRM)
C	BASEHC	 BASE HC TYPE.  Basehc.RXP USED FOR BASE HC.  (.RXP FILES
C		 READ FROM DIRECTORY NAMED BY "RXP=" INPUT IN MODELING.PRM)
C	T.HC	 AMOUNT OF HC INPUT.  CONVERTED DIRECTLY TO "TOT.HC"
C		 IN .INT FILE.  
C	T.NOX	 AMOUNT OF NOX INPUT.  CONVERTED DIRECTLY TO "TOT.NOX"
C		 IN .INT FILE.  (ALSO SETS RNOX TO .FALSE. TO INDICATE
C		 THAT NOX NOT CALCULATED USING HC/NOX RATIO.)
C	HC/NOX	 AMOUNT OF NOX INPUT RELATIVE TO T.HC.  (ALSO SETS RNOX
C		 TO .TRUE. TO INDICATE THAT NOX CALCULATED USING HC/NOX
C		 RATIO.)
C	C/N-COR	 CORRECTION FACTOR USED WHEN CALCULATING NOX FROM HC/NOX
C		 RATIO.  [ TOT.NOX = TOT.HC / ( HC/NOX * C/N-COR ) ]
C	ALOFTHC	 ALOFT HC COMPOSITION (READ FROM alofthc.LMO) IN UIC
C		 NAMED BY "RXP=" INPUT IN MODELING.PRM
C	ALO.HC	 ALOFT HC LEVEL.
C	ALO.O3	 ALOFT O3
C	ALO.NOX	 ALOFT NO2
C	EPS	 INT ERROR CONTROL PARM (USE EPS=1.E-6 FOR SMALL 
C		 MOLRCT, EPS=1.E-4 OK FOR LARGE MOLRCT)
C	*name	 INFORMATIONAL ITEM WHICH IS STORED IN .BAS FILE.
C		 (USED ONLY IN .SCEN INPUT)
C
C	REACTCAL CONTROL CODES READ FROM SCENARIO.PRM:
C
C	CODE	 USE
C	-------- ---------------------------------------------------
C	MOLRCT	 USED TO CALCULATE AMOUNT TEST HC ADDED FOR SCENARIO:
C		 TOT.THC = MOLRCT / (ESTIMATED FRACTION THC REACTS)
C	O3	 CALCULATE REACTIVITY RELATIVE TO O3 (DEFAULT) (O3KODE=0)
C	O3-NO	 CALCULATE REACTIVITY RELATIVE TO O3-NO (O3KODE=1)
C	DECCAL	 DE-INCREMENT CALC NO. (FOR MULTIDAY)
C	NODECCAL DON'T DEINCREMENT CALC NO. (DEFAULT)
C
C
C	INPUT IN [basuic]scenid.BAS
C	    (BASRCT CREATED)
C		FR-KOH	FRACTIONS REACTED AT GIVEN KOH'S
C
C	INPUT USED IN MODELING.PRM .
C
C		MODEL=	LOCATION WHERE BASE CALC OUTUT GOES
C		BASEXT=	(SAME AS ABOVE, FOR COMPATIBILITY)
C		CAL=	CALC UIC
C		MOD=	MODEL UIC
C		MDC=	MODEL VERSION ID
C		INP=	UIC FOR SCENARIO INP FILES
C		RXP=	UIC FOR BASE CASE .RXP FILES.
C		CLC=	UIC FOR REACTIVITY CALC OUTPUT (.BAS, .CLC) DATA
C		TESTHC=	TESTHC DATA FILES (FOR CREATING TESTHC.IN)
C		MOD-BS=	MODEL FOR BASE CASE CALCS
C		MOD-S=	MODEL FOR EXPLICIT SPECIES ("STD") REACTIVITY CALCS
C		MOD-T=	MODEL FOR "PURE PRODUCT" ("T") REACTIVITY CALCS
C		MOD-A=	MODEL FOR ALKANE/AROMATIC ("A") REACTIVITY CALCS
C		MOD-I=	MODEL FOR OLEFIN REACTIVITY ("O") CALCS
C		MOD-MX=	MODEL FOR MIXTURE ("MIX") CALCS
C		MODPRE=	MODEL PREFIX FOR SPECIAL VOC'S.
C
C		EXPLICIT-KOH =	FILE GIVING EXPLICIT MODEL SPECIES, AND
C				PARMS FOR FIGURING FRACTION REACTED.
C
C		MAXCAL=	SPECIES NAMES TO SAVE MAXIMUM CONC'S IN .CLC FILE
C
C	MODEL SPECIES WHERE FRACTION REACTED GIVEN EXPLICITLY IN
C	SCENARIO PRM FILE
C
	PARAMETER (MXFRMS=10,MAXMXC=40)
	INTEGER NFRMS,NMXC
	CHARACTER FRMSNM(MXFRMS)*5,MXCNAM(MAXMXC)*5
	REAL FRMS(MXFRMS),MXCONC(4,MAXMXC)
C
	CHARACTER INLIN*160,SCNID*8,THCID*8,LNAM*5,NAMEIN*8,INLIN2*80
	CHARACTER CALUIC*40,MODDOC*40,MODUIC*40,INPUIC*40,
     &	 BSMOD*8,TMOD*8,AMOD*8,MXMOD*8,OMOD*8,SMOD*8,MODEL*8,MODPRE*8,
     &	 CMDLIN*80,THCFIL*40,RXPUIC*40,EXPKOH*40,SAVFIL*40,CLCUIC*40,
     &	 DOSUIC*40,SCNPRM*40,PRMFIL*8,EXTFIL*8,SCNID2*8,TAB*1,
     &	 MXCLIS*160,MROKOD*8,TSTFIL*60,GMOD*8,TSTID*60,INTID*8,CLMOD*8
C
	PARAMETER (MAXL=8)
	LOGICAL ANS,BASE,NOX,TEST,INTONL,PARMIN,SUBST,ADDIN,CHECK,
     &	 PERCNT,SCNLOG,MAXO,INSO,ERRIND,EXPTHC,HVOUT,INTIN,PRODIN,BADFILE
C
	PARAMETER (MAXFR=12)
	REAL KOH(MAXFR),INTOH(MAXFR)
	COMMON /FRDAT/ KOH,INTOH,NFR
C
	PARAMETER (MAXOPT=8)
	INTEGER LSCNOP(MAXOPT)
	CHARACTER SCNOPT(MAXOPT)*8
C
	REAL NODATA
	PARAMETER (NODATA=-9.9E+9)
C
C	SCENARIO.PRM PARAMETERS
C
	INCLUDE 'SCENSPEC.FOR'
C
C	*** CHANGE THE FOLLOWING TO .TRUE. TO USE CARBON NUMBER WHEN
C		FIGURING FRACTION REACTED.  CURRENTLY PROGRAM DOES NOT PERMIT
C		THIS TO BE CHANGED AS AN INPUT PARAMETER **
	LOGICAL USENC/.FALSE./
C
	TAB=CHAR(9)
C
C	GET AND DECODE COMMAND LINE
C
	CALL GETARG (1,SCNID)
	IF (SCNID(1:1).EQ.' '.OR.SCNID(1:2).EQ.'X ') THEN
		WRITE (6,2)
    2		FORMAT (
     &   /' Use:  REACTCAL scenid TSTID [option ]      Options are:'/
     &   /' INTFILE           Stop after making INT and other tempor',
     &    'ary input files.'
     &   /' ADDED amount [%]  Specify amount added.  (% = amount per',
     &    'centage of base.)'
     &   /' SUBST amount [%]  Specify amount substituted.'
     &   /' NOCHECK           OK to re-calculate reactivity.'
     &   /' SCENLOG           Append summary of scenario characteris',
     &    'tics to REACTCAL.LOG'
     &   /' PRM=prmfile       Use .PRM file to supercede parameters ',
     &    'in MODELING.PRM'
     &   /' NOx-XXX scenid2   Take NOx from "NOx-XXX" line in "scenid',
     &     '2.BAS".'
     &   /' NOX-XXX scenid2   Take NOx from "NOX-XXX" line in "scenid',
     &     '2.BAS".'
     &   /' ROG-XXX scenid2   Take ROG from "ROG-XXX" line in "scenid',
     &     '2.BAS".'
     &   /'                   (The above are calculated by "MROPT sc',
     &    'enid2".)'
     &   /' N=X.XX scenid2    Use X.XX for E.NOX and take other input',
     &     's from "scenid2.BAS".'
     &   /' C=X.XX scenid2    As above, but for E.HC".'
     &   /' X                 Blank option'
     &   //' Use "*" for "TSTID" to produce .INT file with @REACTCAL.',
     &    'IN before the first'/' .SETDEF or .INT.  (Useful for MaxO3',
     &    ' and isopleth calculations.'/
     &   /' O3max and O3dose results of SUBST and ADDED calcs logged ',
     &    'in SUBSTDAT.CSV'/)
		CALL EXIT (2)
	ENDIF
	LSCNID=LNBLNK(SCNID)
C
	SCNLOG=.FALSE.
	CALL GETARG (2,TSTFIL)
	LTSTFL=LNBLNK(TSTFIL)
	IF (TSTFIL(1:2).EQ.'X ') THEN
		TSTFIL=' '
		LTSTFL=0
		LTHCID=0
		THCID=' '
	ELSEIF (TSTFIL(1:2).EQ.'F=') THEN
		TSTFIL=TSTFIL(3:)
		LTSTFL=LTSTFL-2
		THCID='TESTVOC'
		LTHCID=7
	ELSE
		LTHCID=MIN(LTSTFL,8)
		THCID=TSTFIL(1:LTHCID)
		TSTFIL=" "
		LTSTFL=0
	ENDIF
C
	CALL GETARG(3,CMDLIN)
	IF (CMDLIN(1:2).EQ.'X ') CMDLIN=' '
C
	MIRMOR=0
	MROKOD=' '
	IF (THCID(1:4).EQ.'NOX-'.OR.THCID(1:4).EQ.'NOx-'
     &	 .OR.THCID(1:4).EQ.'NOx#') THEN
		MIRMOR=1
		MROKOD=THCID
	ELSEIF (THCID(1:4).EQ.'ROG-') THEN
		MIRMOR=2
		MROKOD=THCID
	ELSEIF (THCID.EQ.'SCENLOG ') THEN
		SCNLOG=.TRUE.
	ELSEIF (THCID(1:2).EQ.'N=') THEN
		MIRMOR=3
		MROKOD=THCID(3:8)//'  '
	ELSEIF (THCID(1:2).EQ.'C=') THEN
		MIRMOR=4
		MROKOD=THCID(3:8)//'  '
	ENDIF
C
	IF (MIRMOR.NE.0) THEN
		IF (CMDLIN(1:1).EQ.' ') THEN
			WRITE (6,*) 'No scenario given for ',
     &			 THCID(1:7),'.'
			CALL EXIT (2)
		ENDIF
		SCNID2=CMDLIN(1:8)
		LSID2=LNBLNK(SCNID2)
		THCID='BASE    '
		LTHCID=4
		CALL GETARG (4,CMDLIN)
		LC=5
	ELSE
		SCNID2=SCNID
		LSID2=LSCNID
		LC=4
	ENDIF
C
C    	CHECK=LTSTFL.EQ.0
	CHECK=.TRUE.
	SUBST=.FALSE.
	ADDIN=.FALSE.
	PRMFIL=' '
	LPRMFL=0
	INTONL=.FALSE.
    3	IF (CMDLIN(1:1).EQ.' ') THEN
		CONTINUE
	ELSEIF (CMDLIN(1:8).EQ.'INTFILE') THEN
		INTONL=.TRUE.
		N=0
	ELSEIF (CMDLIN(1:8).EQ.'NOCHECK ') THEN
		CHECK=.FALSE.
	ELSEIF (CMDLIN(1:6).EQ.'ADDED ') THEN
		CALL GETARG(LC,INLIN)
		ADDED=REALV(INLIN,LNBLNK(INLIN),ANS)
		IF (ANS) GOTO 901
		ADDIN=.TRUE.
	ELSEIF (CMDLIN(1:6).EQ.'SUBST ') THEN
		CALL GETARG (LC,INLIN)
		ADDED=REALV(INLIN,LNBLNK(INLIN),ANS)
		IF (ANS) GOTO 901
		ADDIN=.TRUE.
		SUBST=.TRUE.
	ELSEIF (CMDLIN(1:8).EQ.'SCENLOG ') THEN
		IF (THCID(1:1).NE.' '.AND.THCID.NE.'BASE    ') THEN
			WRITE (6,*) 'SCNLOG option can only be used',
     &			 ' for BASE CASE calculations.'
			CALL EXIT (2)
		ENDIF
		SCNLOG=.TRUE.
	ELSEIF (CMDLIN(1:4).EQ.'PRM=') THEN
		PRMFIL=CMDLIN(5:)
		LPRMFL=LNBLNK(PRMFIL)
	ELSE
		WRITE (6,*) 'Unrecognized option = '//CMDLIN(1:40)
		CALL EXIT (2)
	ENDIF
C
C
	IF (ADDIN.OR.SUBST) THEN
C
		CALL GETARG (LC+1,NAMEIN)
		PERCNT=NAMEIN(1:2).EQ.'% '
		IF (SUBST) THEN
			CALL PARSE0 (2,CMDLIN,40)
			CALL PARSER (2,SUBFAC,ANS,CMDLIN)
			IF (ANS.OR.SUBFAC.EQ.0.0) THEN
				SUBFAC=1.0
			ELSEIF (SUBFAC.LT.0.0) THEN
				SUBFAC=-1.0/SUBFAC
			ENDIF
		ENDIF
	ELSE
		PERCNT=.FALSE.
	ENDIF
C
C	SEE IF THIS IS BASE CASE OR TEST CALC.
C
	IF (THCID(1:1).EQ.' ') THEN
		THCID='BASE    '
		LTHCID=4
		IF (.NOT.SCNLOG) WRITE (6,*) 'BASE CASE ASSUMED'
		BASE=.TRUE.
		NOX=.FALSE.
		MAXO=.FALSE.
	ELSEIF (LTHCID.EQ.4.AND.THCID(1:4).EQ.'BASE') THEN
		BASE=.TRUE.
		NOX=.FALSE.
		MAXO=.FALSE.
	ELSEIF (LTHCID.EQ.3.AND.THCID(1:3).EQ.'NOX') THEN
		BASE=.FALSE.
		NOX=.TRUE.
		MAXO=.FALSE.
	ELSE IF (THCID(1:1).EQ.'+') THEN
		BASE=.FALSE.
		NOX=.FALSE.
		MAXO=.TRUE.
	ELSE
		BASE=.FALSE.
		NOX=.FALSE.
		MAXO=.FALSE.
	ENDIF
	INSO=MAXO
C
	IF (BASE.OR.MAXO) THEN
		INTID=SCNID
		LINTID=LSCNID
	ELSE
		INTID='REACTCAL'
		LINTID=8
	ENDIF
C
C	DEFAULT VOC CHARACTERISTICS
C
	TSTMWT=0.0
	TSTNC=0.0
	TSTID=" "
C
C	GET PARMS FROM MODELING.PRM, THEN PRMFILE, IF SPECIFIED.
C
	LSCNTP=0
	SCNTYP=' '
C
	LCALUC=2
	CALUIC='.\'
	LMODUC=0
	MODUIC=' '
	LMODDC=0
	MODDOC=' '
	LINPUC=0
	INPUIC=' '
	LTHCFL=0
	THCFIL=' '
	LRXPUC=0
	RXPUIC=' '
	LCLCUC=0
	CLCUIC=' '
	LDOSUC=0
	DOSUIC=' '
	LEXPK=0
	EXPKOH=' '
	LBSMOD=0
	BSMOD=' '
	LTMOD=0
	TMOD=' '
	LSMOD=0
	SMOD=' '
	LAMOD=0
	AMOD=' '
	LMXMOD=0
	MXMOD=' '
	LCLMOD=0
	CLMOD=' '
	LIMOD=0
	OMOD=' '
	LGMOD=0
	GMOD=' '
	LMODPR=0
	MODPRE=' '
	LSPMFL=12
	SCNPRM='SCENARIO.PRM'
	MXCLIS=' '
	NFR=0
	INTIN=.FALSE.
	TEMP=300.0	! DEFAULT TEMPERATURE FOR K CONV FOR EXPLICIT PARMS
	EXTFIL=' '
	LEXTFL=0
	OPEN (UNIT=1,FILE='MODELING.PRM',STATUS='UNKNOWN')
	ANS=.TRUE.
C
  100	READ (1,1,END=110) INLIN
    1	FORMAT (A)
	L=LNBLNK(INLIN)
	IF (L.LT.5) GOTO 100
C
	IF (INLIN(1:4).EQ.'CAL=') THEN
		LCALUC=L-4
		CALUIC=INLIN(5:L)
	ELSEIF (INLIN(1:4).EQ.'MOD=') THEN
		LMODUC=L-4
		MODUIC=INLIN(5:L)
	ELSEIF (INLIN(1:4).EQ.'MDC=') THEN
		LMODDC=L-4
		MODDOC=INLIN(5:L)
	ELSEIF (INLIN(1:4).EQ.'INP=') THEN
		LINPUC=L-4
		INPUIC=INLIN(5:L)
	ELSEIF (INLIN(1:7).EQ.'TESTHC=') THEN
		LTHCFL=L-7
		IF (LTHCFL.GT.0) THCFIL=INLIN(8:L)
	ELSEIF (INLIN(1:7).EQ.'MOD-BS=') THEN
		LBSMOD=L-7
		IF (LBSMOD.GT.0) BSMOD=INLIN(8:L)
	ELSEIF (INLIN(1:6).EQ.'MOD-T=') THEN
		LTMOD=L-6
		IF (LTMOD.GT.0) TMOD=INLIN(7:L)
	ELSEIF (INLIN(1:6).EQ.'MOD-A=') THEN
		LAMOD=L-6
		IF (LAMOD.GT.0) AMOD=INLIN(7:L)
	ELSEIF (INLIN(1:6).EQ.'MOD-S=') THEN
		LSMOD=L-6
		IF (LSMOD.GT.0) SMOD=INLIN(7:L)
	ELSEIF (INLIN(1:6).EQ.'MOD-I=') THEN
		LIMOD=L-6
		IF (LIMOD.GT.0) OMOD=INLIN(7:L)
	ELSEIF (INLIN(1:6).EQ.'MOD-G=') THEN
		LGMOD=L-6
		IF (LGMOD.GT.0) GMOD=INLIN(7:L)
	ELSEIF (INLIN(1:7).EQ.'MOD-CL=') THEN
		LCLMOD=L-7
		IF (LCLMOD.GT.0) CLMOD=INLIN(8:L)
	ELSEIF (INLIN(1:7).EQ.'MOD-MX=') THEN
		LMXMOD=L-7
		IF (LMXMOD.GT.0) MXMOD=INLIN(8:L)
	ELSEIF (INLIN(1:7).EQ.'MODPRE=') THEN
		LMODPR=L-7
		IF (LMODPR.GT.0) MODPRE=INLIN(8:L)
	ELSEIF (INLIN(1:4).EQ.'RXP=') THEN
		LRXPUC=L-4
		IF (LRXPUC.GT.0) RXPUIC=INLIN(5:L)
	ELSEIF (INLIN(1:4).EQ.'CLC=') THEN
		LCLCUC=L-4
		IF (LCLCUC.GT.0) CLCUIC=INLIN(5:L)
	ELSEIF (INLIN(1:7).EQ.'DOSCLC=') THEN
		LDOSUC=L-7
		IF (LDOSUC.GT.0) DOSUIC=INLIN(8:L)
	ELSEIF (INLIN(1:13).EQ.'EXPLICIT-KOH=') THEN
		LEXPK=L-13
		IF (LEXPK.GT.0) EXPKOH=INLIN(14:L)
	ELSEIF (INLIN(1:9).EQ.'SCENPARM=') THEN
		LSPMFL=L-9
		IF (LSPMFL.GT.0) THEN
			SCNPRM=INLIN(10:L)
		ELSE
			LSPMFL=12
			SCNPRM='SCENARIO.PRM'
		ENDIF
	ELSEIF (INLIN(1:7).EQ.'MAXCAL=') THEN
		MXCLIS=INLIN(8:)
	ELSEIF (INLIN(1:9).EQ.'MODELSET=') THEN
		LEXTFL=L-9
		EXTFIL=INLIN(10:)
	ELSEIF (INLIN(1:6).EQ.'INTIN:'.OR.INLIN(1:6).EQ.'INTIN=') THEN
C	      - "INTIN:"  COPY INPUT WITH BLANK IN COLUMN 1 UNTIL
C		 NOLNBLNK IN COL 1.  COPY TO TMP.IN.  THIS IS INSERTED
C		 RIGHT BEFORE THE FIRST .INT OR .SETDEF LINE.
		OPEN (UNIT=8,FILE='TMP.IN',STATUS='UNKNOWN')
		INTIN=.TRUE.
   14		READ (1,1,END=15) INLIN
		IF (INLIN(1:1).NE.' ') THEN
			CLOSE (UNIT=8)
			GOTO 100
		ELSE
			L=LNBLNK(INLIN)
			IF (L.GE.2) WRITE (8,1) INLIN(2:L)
			GOTO 14
		ENDIF
   15		CLOSE (UNIT=8)
	ELSEIF (INLIN(1:7).EQ.'BASEXT=') THEN
		EXTFIL=INLIN(8:)
		LEXTFL=L-7
	ENDIF
C
	GOTO 100
C
  110	CONTINUE
C
C	PRM FILE OR BASE EXT MUST BE SPECIFIED.
C	READ PRM FILE IF NEEDED.
C
	IF (ANS) THEN
		IF (LEXTFL.EQ.0) THEN
			EXTFIL=PRMFIL
			LEXTFL=LPRMFL
		ELSEIF (LPRMFL.GT.0) THEN
			CLOSE (UNIT=1)
			OPEN (UNIT=1,FILE=PRMFIL(1:LPRMFL)//'.PRM',
     &			 STATUS='OLD',ERR=113)
			ANS=.FALSE.
			GOTO 100
C
  113			WRITE (6,*) 'File = ',PRMFIL(1:LPRMFL),
     &			 '.PRM does not exist.'
			CALL EXIT (2)
		ENDIF
	ENDIF
C
C	MODELSET MUST BE SPECIFIED IN MODELING.PRM OR PARAMETER FILE
C	MUST BE NAMED
C
	IF (LEXTFL.EQ.0) THEN
		WRITE (6,*) 'MODEL must be specified in modeling.prm'
     &		 //' or a parameter file (PRM=input) must be specified.'
		CALL EXIT (2)
	ENDIF
C
C	IF THIS IS A "ADDED OR SUBST" CALC WITH NOTHING ADDED OR
C	SUBSTITUTED, THEN JUST LOG BASE RESULT.
C
	IF (ADDIN.AND.ADDED.EQ.0.0) THEN
		INLIN=CLCUIC
		INLIN(LCLCUC+1:LCLCUC+LSCNID)=SCNID(1:LSCNID)
		INLIN(LCLCUC+LSCNID+1:LCLCUC+LSCNID+4)='.BAS'
		OPEN (UNIT=3,FILE=INLIN,STATUS='OLD')
		INLIN=SCNID//',,,,'
		CALL LOGCHG (.TRUE.,3,INLIN,12,'SUBSTDAT.CSV')
		CALL EXIT (0)
	ENDIF
C
C	DECODE MAXCAL INPUT. IF .PRM FILE DOES NOT A MAXCAL=O3, THEN ADD
C	IT.  O3 MUST BE FIRST ON LIST.  (ONLY NEEDED IF BASE CALC.)
C
	NMXC=1
	MXCNAM(1)='O3'
	IF (BASE) THEN
		IF (MXCLIS(1:1).EQ.' ') THEN
			WRITE (1,*) 'MAXCAL=O3'
		ELSE
			IF (MXCLIS(1:1).EQ.'@') THEN
				ERRIND=.FALSE.
				OPEN (UNIT=3,FILE=MXCLIS(2:),STATUS='OLD',
     &				 ERR=942)
				NMXC=0
 1135				READ (3,1,END=1136) NAMEIN
				IF (NAMEIN(1:1).NE.' '.AND.NAMEIN(1:1).NE.'!') THEN
					IF (NMXC.EQ.MAXMXC) STOP 'INCREASE MAXMXC'
					NMXC=NMXC+1
					MXCNAM(NMXC)=NAMEIN(1:5)
				ENDIF
				GOTO 1135
 1136				CLOSE (UNIT=3)
			ELSE
				ERRIND=.TRUE.
				CALL PARSE0 (MAXMXC,MXCLIS,160)
				DO 1132 I=1,MAXMXC
				CALL PARSE1 (I,NAMEIN,L,8,MXCLIS)
				IF (NAMEIN(1:1).EQ.' ') GOTO 1134
				IF (NAMEIN(1:3).NE.'O3 ') THEN
					NMXC=NMXC+1
					MXCNAM(NMXC)=NAMEIN(1:5)
				ELSEIF (I.EQ.1) THEN
					ERRIND=.FALSE.
				ENDIF
 1132				CONTINUE
 1134				CONTINUE
			ENDIF
			IF (ERRIND) THEN
				IF (NMXC.EQ.1) THEN
					WRITE (1,*) 'MAXCAL=O3'
				ELSE
					WRITE (1,*) 'MAXCAL=O3',(' ',
     &					 MXCNAM(I)(1:LNBLNK(MXCNAM(I)))
     &					 ,I=2,NMXC)
				ENDIF
			ENDIF
		ENDIF
	ENDIF
	CLOSE (UNIT=1)
C
C
	IF (LDOSUC.NE.0.AND.(CLCUIC.EQ.DOSUIC)) THEN
		WRITE (6,*) 'Error in MODELING.PRM.'
		WRITE (6,*) 'Can''t have ''CLC='' and ''DOSCLC='' ',
     &		 'refer to the same directory.'
		GOTO 990
	ENDIF
C
C
C	IF NOT BASE CALC, OR IF CALC WITH "MIR" OR "MOR" OPTIONS,
C	GET SCENARIO PRMS FROM .BAS FILE.
C
	IF ((.NOT.BASE).OR.MIRMOR.NE.0) THEN
		IF (LCLCUC.EQ.0) THEN
			INLIN=SCNID2(1:LSID2)//'.BAS'
			LF=LSID2+4
		ELSE
			INLIN=CLCUIC(1:LCLCUC)//SCNID2(1:LSID2)//'.BAS'
			LF=LCLCUC+LSID2+4
		ENDIF
		OPEN (UNIT=1,FILE=INLIN(1:LF),STATUS='OLD',ERR=900)
		READ (1,1) CMDLIN
		IF (CMDLIN(9:8+LSID2).NE.SCNID2(1:LSID2)) THEN
			WRITE (6,*) 'WARNING:  ScenID in file = ',
     &			 INLIN(1:LF),' does not match.'
		ENDIF
		IF (MIRMOR.NE.0) THEN
			IF (MIRMOR.LE.2) THEN
				WRITE (6,*) MROKOD(1:3),' for ',
     &				 MROKOD(5:LNBLNK(MROKOD)),' read fro',
     &				 'm file = ',INLIN(1:LF)
			ELSE
				READ (MROKOD,'(F8.0)',ERR=1141) HCNOX
				GOTO 1142
 1141				WRITE (6,*) 'BAD PARAMETER: '//MROKOD
				GOTO 990
 1142				CONTINUE
				IF (MIRMOR.EQ.3) THEN
					WRITE (6,*) 'Use E.NOX= ',HCNOX
				ELSEIF (MIRMOR.EQ.4) THEN
					WRITE (6,*) 'Use E.HC= ',HCNOX
				ENDIF
			ENDIF
			WRITE (6,*) 'Other parms read from '//INLIN(1:LF)
		ENDIF
C
C		INITIALIZE AND READ SCENARIO PARAMETERS
C
		CALL SPINIT
C
		CORFAC=0.0
		O3MAX=0.0
		BASDAT=NODATA
		NFRMS=0
		O3KODE=0
C
C		READ SCEN PARAMETERS (UP TO "ENDPARMS")
C
  115		READ (1,1,END=117) INLIN
		IF (INLIN(1:8).EQ.'ENDPARMS') GOTO 1161
		CALL PARSE0 (2,INLIN,80)
		CALL PARSE1 (1,SCNOPT(1),L,8,INLIN)
		CALL RDSOPT (SCNOPT(1),L,2,INLIN)
		GOTO 115
C
C		READ RESULTS OF CALCULATIONS TO GET:
C			- RESULTS OF BASE CALC, IF TEST.
C			- "CORRECTION" RELATING AMOUNT AT END TO
C			AMOUNT ADDED.  ALSO GET O3MAX, WHICH IS USED ONLY
C			FOR "MAXO" OPTION.
C			- "NOX-MIR", ETC. FOR NOX OR VOC, IF NEEDED.
C			- LIST OF SPECIES (BESIDES O3) TO CALC MAX CONC 
C
C		INITIALIZE
C
 1161		IF (MIRMOR.EQ.1) THEN
			NOXLVL=-1.0
		ELSEIF (MIRMOR.EQ.2) THEN
			HCLVL=-1.0
			CALL PARSE0 (2,INLIN,80)
			CALL PARSER (2,HCLVL,ANS,INLIN)
		ELSEIF (MIRMOR.EQ.3) THEN
			NOXLVL=HCNOX
		ELSEIF (MIRMOR.EQ.4) THEN
			HCLVL=HCNOX
		ENDIF
C
C
  116		READ (1,1,END=117) INLIN
		IF (INLIN(1:1).EQ.' '.OR.INLIN(1:1).EQ.'!') GOTO 116
		IF (INLIN(1:5).EQ.'CORR ') THEN
			CALL PARSE0 (2,INLIN,80)
			CALL PARSER (2,CORFAC,ANS,INLIN)
			IF (ANS.OR.CORFAC.LE.0.0) GOTO 118
		ELSEIF (MAXO.AND.INLIN(1:5).EQ.'O3MAX') THEN
			CALL PARSE0 (2,INLIN,80)
			CALL PARSER (2,O3MAX,ANS,INLIN)
			IF (ANS) GOTO 118
		ELSEIF (INLIN(1:8).EQ.MROKOD) THEN
			IF (MIRMOR.LE.0.OR.MIRMOR.GT.2) GOTO 116
			CALL PARSE0 (2,INLIN,80)
			IF (MIRMOR.EQ.1) THEN
				CALL PARSER (2,NOXLVL,ANS,INLIN)
			ELSEIF (MIRMOR.EQ.2) THEN
				CALL PARSER (2,HCLVL,ANS,INLIN)
			ENDIF
			IF (ANS) GOTO 118
		ELSEIF (.NOT.BASE) THEN
			IF (O3KODE.NE.1.AND.INLIN(1:6).EQ.'MAXO3 ') THEN
				CALL PARSER (2,BASDAT,ANS,INLIN)
				IF (ANS) GOTO 118
			ELSEIF (O3KODE.EQ.1.AND.INLIN(1:6).EQ.'O3MNO ')
     &			 THEN
				CALL PARSER (2,BASDAT,ANS,INLIN)
				IF (ANS) GOTO 118
			ELSEIF (INLIN(1:3).EQ.'MAX') THEN
				IF (NMXC.GE.1) THEN
					DO 1162 I=1,NMXC
					IF (INLIN(4:8).EQ.MXCNAM(I)(1:5)
     &					 ) GOTO 1163
 1162					CONTINUE
				ENDIF
				IF (NMXC.LT.MAXMXC) THEN
					NMXC=NMXC+1
					MXCNAM(NMXC)=INLIN(4:8)
				ENDIF
 1163				CONTINUE
			ENDIF
		ENDIF
C
C		IF TEST CALC, READ FRACTIONS REACTED DATA FROM scenid.BAS
C		(DON'T NEED TO DO THIS FOR NOX REACTIVITY)
C
		IF (BASE.OR.NOX) GOTO 116
C
		IF (INLIN(1:3).EQ.'FR-') THEN
			IF (INLIN(4:7).EQ.'KOH ') THEN
				CALL PARSE0 (2,INLIN(7:80),74)
				CALL PARSER (1,RKI,ANS,INLIN(7:80))
				IF (ANS) GOTO 116
				CALL PARSER (2,RFI,ANS,INLIN(7:80))
				IF (ANS) GOTO 116
				CALL ADDFR (RKI,RFI)
			ELSE
				IF (NFRMS.EQ.MXFRMS) THEN
					WRITE (6,*) 'Too much "FR-"',
     &					 ' input in',SCNID(1:LSCNID),
     &					 '.PRM.'
					GOTO 990
				ENDIF
				NFRMS=NFRMS+1
				CALL PARSE0 (2,INLIN(4:80),77)
				CALL PARSE1 (1,FRMSNM(NFRMS),L,5,
     &				 INLIN(4:80))
				CALL PARSER (2,FRMS(NFRMS),ANS,
     &				 INLIN(4:80))
				IF (ANS.OR.FRMSNM(NFRMS)(1:1).EQ.' ')
     &				 NFRMS=NFRMS-1
			ENDIF
		ENDIF
C
		GOTO 116
C
C		DONE READING.   SEE IF REQUIRED DATA OBTAINED
C
 117		CLOSE (UNIT=1)
		IF (CORFAC.EQ.0.0.AND.(.NOT.MAXO)) THEN
			INLIN='CORR not defined.'
			GOTO 118
		ELSEIF (MAXO.AND.O3MAX.EQ.0.0) THEN
			INLIN='O3MAX not defined.'
			GOTO 118
		ELSEIF (NOXLVL.LT.0.0) THEN
			INLIN='NOX for MIR or MOR not defined.'
			GOTO 118
		ELSEIF (HCLVL.LT.0.0) THEN
			INLIN='HC for MIR or MOR not defined.'
			GOTO 118
		ELSEIF (BASDAT.EQ.NODATA.AND.(.NOT.BASE)) THEN
			IF (O3KODE.EQ.1) THEN
				INLIN='O3MNO'
			ELSE
				INLIN='MAXO3'
			ENDIF
			INLIN(6:)=' not defined.'
			GOTO 118
		ELSEIF (.NOT.(BASE.OR.NOX)) THEN		
C			IF (NFRMS.EQ.0) THEN
C				INLIN='No FR-KOH input.'
C				GOTO 118
C			ENDIF
			IF (MOLRCT.LE.0.0) THEN
				INLIN='No MOLRCT input.'
				GOTO 118
			ENDIF
		ENDIF
C
C		CHANGE SCNTYP TO TSTINP IF THIS IS A TEST CALCULATION 
C		AND TSTINP IS INPUT.
C
		IF ((.NOT.BASE).AND.TSTINP(1:1).NE.' ') THEN
			SCNTYP=TSTINP
			LSCNTP=LTSTIN
		ENDIF
C
C		IF ONLY BUILDING .INT FILE FOR TEST CALCULATION,
C		SET MODEL TYPE TO "STANDARD, THEN JUMP RIGHT TO
C		CODE TO BUILD .INT FILE.
C
		IF (MAXO) THEN
			MODEL=SMOD
			LMOD=LSMOD
			GOTO 199
		ENDIF
C
C		SUCCESSFULLY FINISHED READING .BAS FILE.  JUMP PAST
C		SECTION READING SCENPRM FILR.
C
C
		GOTO 129
C
C		ERROR READING .BAS FILE
C
  118		CLOSE (UNIT=1)
		WRITE (6,*) 'Bad or missing data in ',
     &		 SCNID2(1:LSID2),'.BAS.'
		WRITE (6,*) 'Message or bad input = "',
     &		 INLIN(1:LNBLNK(INLIN)),'"'
		CALL EXIT (2)
C
	ENDIF
C
C
C	IF BASE CALC, GET SCEN INFO FROM SCENPRM FILE
C
C
	TEST=.FALSE.
C
	OPEN (UNIT=1,FILE=SCNPRM(1:LSPMFL),STATUS='OLD',ERR=902)
C
C	INITIALIZE SCENARIO PARAMETERS
C
  111	CALL SPINIT
C
  120	READ (1,1,END=128) INLIN
	IF (INLIN(1:1).EQ.'!'.OR.INLIN(1:1).EQ.' ') GOTO 120
C
C	".command"  .. SPECIAL SCENARIO COMMAND
C
	IF (INLIN(1:1).EQ.'.') THEN
C
		IF (INLIN(2:6).EQ.'SCEN ') THEN
C
C			.SCEN 		READ SCENARIO NAME AND OPTIONS 
C					TO READ FROMLINE WITH NAME
C					(MAX = MAXOPT)
C
			CALL PARSE0 (MAXOPT,INLIN(7:80),74)
			DO 122 I=1,MAXOPT
			CALL PARSE1(I,SCNOPT(I),LSCNOP(I),8,INLIN(7:80))
			IF (LSCNOP(I).EQ.0) THEN
				NSOPT=I-1
				GOTO 123
			ENDIF
  122			CONTINUE
			NSOPT=MAXOPT
C
C			READ NEXT SCENARIO NAME.  '.' BY ITSELF OR BLANK
C			ENDS .SCEN INPUT.
C
  123			READ (1,1,END=128) INLIN
			IF (INLIN(1:1).EQ.'!') GOTO 123
			IF (INLIN(1:1).EQ.' '.OR.INLIN(1:1).EQ.'.')
     &			 GOTO 120
C			- DONE WITH SEARCH IF THIS MATCHES INPUT SCENARIO
C			  (AND FOLLOWED BY BLANK CHAR)
			IF (INLIN(1:LSCNID).EQ.SCNID) THEN
				IF (INLIN(LSCNID+1:LSCNID+1).EQ.' ')
     &				 GOTO 130
			ENDIF
			GOTO 123
C
		ELSEIF (INLIN(2:7).EQ.'RESET ') THEN
C
C			.RESET		READ NEW SET OF OPTIONS
C
			GOTO 111
C
		ELSEIF (INLIN(2:6).EQ.'TEST ') THEN
C
C			.TEST	OUTPUT SCEN PARMS FOR DEBUGGING
C
			TEST=.TRUE.
C
		ELSE
C
C			UNRECOGNIZED .command
C
			WRITE (6,*) 'Unrecognized input in ',
     &			 SCNPRM(1:LSPMFL), ' ignored.   Input = ',
     &			 INLIN(1:20)
C
		ENDIF
C
	ELSE
C
C		DECODE OPTION
C
		CALL PARSE0 (2,INLIN,80)
		CALL PARSE1 (1,SCNOPT(1),L,8,INLIN)
		CALL RDSOPT (SCNOPT(1),L,2,INLIN)
C
	ENDIF
C
C	LOOP BACK TO NEXT SCENARIO.PRM OPTION
C
	GOTO 120
C
  128	WRITE (6,*) 'Scenario = ',SCNID(1:LSCNID),
     &	' not found in ',SCNPRM(1:LSPMFL)
	CLOSE (UNIT=1)
	GOTO 990
C
C	SCENARIO FOUND.  CLOSE FILE, AND DECODE OPTIONS GIVEN WITH
C	NAME.

  130	CLOSE (UNIT=1)
C
	IF (NSOPT.NE.0) THEN
		CALL PARSE0 (NSOPT+1,INLIN,80)
		DO 132 I=1,NSOPT
		CALL RDSOPT (SCNOPT(I),LSCNOP(I),I+1,INLIN)
  132		CONTINUE
	ENDIF
C
C
	IF (RNOX) THEN
		IF (NOXRAT.NE.0.0) THEN
			NOXLVL=HCLVL/(NOXRAT*CNCOR)
		ELSE
			NOXLVL=0.0
		ENDIF
	ELSE
		IF (NOXLVL.NE.0.0) THEN
			NOXRAT=HCLVL/(NOXLVL*CNCOR)
		ELSE
			NOXRAT=0.0
		ENDIF
	ENDIF
C
C	OUTPUT PARMS FOR DEBUGGING, IF NEEDED
C
	IF (TEST) THEN
		OPEN (UNIT=1,FILE='TEST.OUT',STATUS='UNKNOWN')
		CALL SOPOUT (1,SCNID,.FALSE.)
		CLOSE (UNIT=1)
		STOP 'TEST.OUT WRITTEN'
	ENDIF
C
C	CONTROL GOES BACK HERE FOR BOTH TEST AND BASE
C
  129	CONTINUE
C
C	LOG SCENARIO ID'S IF "SCNLOG" OPTION GIVEN
C
	IF (SCNLOG) THEN
		INQUIRE (FILE='REACTCAL.LOG',EXIST=ANS)
		IF (ANS) THEN
			OPEN (UNIT=3,FILE='REACTCAL.LOG',STATUS='OLD',
     &			 ACCESS='APPEND')
			WRITE (6,*) 'File = REACTCAL.LOG updated.'
		ELSE
			OPEN (UNIT=3,FILE='REACTCAL.LOG',STATUS='NEW')
			WRITE (3,1) 'SCNTYP   BHCID      HC-LVL  '//
     &			 'NOX-LVL  ALOFTID   ALO-HC  ALO-O3  ALO-NOX'
			WRITE (6,*) 'File = REACTCAL.LOG created.'
		ENDIF
		WRITE (3,'(A8,1X,A8,2F9.3,2X,A8,3F8.3)') SCNTYP,BHCID,
     &		 HCLVL,NOXLVL,AHCID,AHCLVL,AO3LVL,ANOXLV
		CLOSE (UNIT=3)
		CALL EXIT (0)
	ENDIF
C
C
C	** START PROCESSING SCENARIO WITH INPUT PARMS **
C
C	READ TESTFILE IF USED TO GET VOC ID.  KEEP OPEN TO READ PARMS.
C
	IF (LTSTFL.NE.0) THEN
C
C		PROCESS VOC FOR DIRECT PARM INPUT, GIVEN IN TSTFIL
C
		OPEN (UNIT=1,FILE=TSTFIL(1:LTSTFL),STATUS='OLD',ERR=912)
		MODEL=GMOD
		LMOD=LGMOD
		EXPTHC=.FALSE.
		FACRCT=0.0
		BADFILE=.FALSE.
C		READ PAST PARMS.  VOC NAME EXPECTED TO BE NEXT NON-COMMENT
C		RECORD.
 170		READ (1,1,END=922) INLIN
		IF (INLIN(1:6).EQ.'PARMS ') THEN
			READ (INLIN,'(5X,I5)',ERR=172) N
			IF (N.EQ.0) GOTO 172
			N=(N/8)+1
			READ (1,1) (INLIN(1:1),I=1,N)
		ELSEIF (INLIN(2:7).EQ.'PARMS ') THEN
			BADFILE=.TRUE.
			READ (INLIN(2:),'(5X,I5)',ERR=172) N
			IF (N.EQ.0) GOTO 172
			N=(N/8)+1
			READ (1,1) (INLIN(1:1),I=1,N)
		ELSE
			GOTO 170
		ENDIF
  172		READ (1,1,END=922) INLIN
		IF (BADFILE) INLIN=INLIN(2:)
		IF (INLIN(1:1).EQ.'!'.OR.INLIN(1:1).EQ.' ') GOTO 172
		CALL PARSE0 (3,INLIN,80)
		CALL PARSE1 (1,THCID,LTHCID,8,INLIN)
		CALL PARSE1 (3,TSTID,LTSTID,60,INLIN)
	ENDIF
C
C	IF NEW TEST CALC.  SEE IF THIS ONE HAS BEEN DONE SINCE LAST
C	BASE CALC (SEE IF IT IS IN .CLC FILE AFTER LAST "BASE"
C	ENTRY).  IF SO, DON'T REDO CALCULATION.
C
C	NOTE:  CONTROL REACHES HERE FOR BOTH BASE AND TEST CALCS.
C
	IF (CHECK.AND.
     &	 ((.NOT.(BASE.OR.ADDIN)).AND.(.NOT.INTONL))) THEN
C
		IF (LCLCUC.GT.0) THEN
			INLIN=CLCUIC(1:LCLCUC)
			INLIN(LCLCUC+1:LCLCUC+LSCNID)=SCNID(1:LSCNID)
			LF=LCLCUC+LSCNID+4
			INLIN(LCLCUC+LSCNID+1:LF)='.CLC'
		ELSE
			INLIN=SCNID(1:LSCNID)
			LF=LSCNID+4
			INLIN(LSCNID+1:LF)='.CLC'
		ENDIF
		OPEN (UNIT=9,FILE=INLIN,STATUS='OLD',ERR=900)
C
		ANS=.FALSE.
 134		READ (9,1,END=136) INLIN
		IF (INLIN(1:5).EQ.'BASE ') THEN
			ANS=.FALSE.
		ELSEIF (INLIN(1:8).EQ.THCID) THEN
			IF (LTSTFL.NE.0) THEN
				IF (INLIN(100:100).EQ.' '.AND.
     &				 INLIN(101:101).NE.' ') ANS=.TRUE.
			ELSE
				ANS=.TRUE.
			ENDIF
		ENDIF
		GOTO 134
C
 136		CLOSE (UNIT=9)
		IF (ANS) THEN
			WRITE (6,*) 'Calculation for ',
     &			 THCID(1:LTHCID),' already done.'
			CALL EXIT (0)
		ENDIF
	ENDIF
C
C
C	GET MODEL TYPE.  FOR TESTHC, SEE IF "EXPLICIT" (LISTED ON
C	EXPKOH FILE).  IF NOT, OPEN TESTHC FILE AND READ
C	TO THIS ONE.  KEEP IT OPEN ON UNIT=1
C
	IF (BASE) THEN
		MODEL=BSMOD
		LMOD=LBSMOD
	ELSEIF (NOX) THEN
		MODEL=SMOD
		LMOD=LSMOD
	ELSEIF (LTSTFL.NE.0) THEN
C
C		PROCESS VOC FOR DIRECT PARM INPUT, GIVEN IN TSTFIL
C		(THIS WAS DONE ABOVE)
C
	ELSE
C
C		EXPLICIT TEST VOC
C
		IF (THCID(5:8).EQ.'    ') THEN
			CALL EXPLSP (THCID,I,TSTNC,EXPKOH,-LEXPK,1)
C ** TEMPORARILY DISABLED USE OF EXPTHC TO FORCE MODEL NAME SAME AS DMS NAME **
			EXPTHC=I.EQ.1
			IF (EXPTHC) THEN
				MODEL=SMOD
				LMOD=LSMOD
				GOTO 159
			ENDIF
		ELSE
			EXPTHC=.FALSE.
		ENDIF
C
C		TEST VOC FROM TESTHC FILE
C
		OPEN (UNIT=1,FILE=THCFIL,STATUS='OLD',ERR=910)
 150		READ (1,1,END=920) INLIN
		IF (INLIN(1:2).NE.'##') GOTO 150
		IF (INLIN(3:10).NE.THCID) GOTO 150
C
C		CODE FOLLOWING NAME GIVES:
C			P1 = MODEL CODE
C			P2 = ESTIMATED AMOUNT REACTED (0=CALCULATE IT)
C
 151		READ (1,1) INLIN
		IF (INLIN(1:1).EQ.'!'.OR.INLIN(1:2).EQ.'##') GOTO 151
		CALL PARSE0 (3,INLIN,80)
		CALL PARSE1 (1,NAMEIN,L,8,INLIN)
		CALL PARSER (2,FACRCT,ANS,INLIN)
		IF (ANS) FACRCT=0.0
		CALL PARSER (3,TSTNC,ANS,INLIN)
		IF (ANS.OR.TSTNC.EQ.0.0) TSTNC=1.0
C
		IF (NAMEIN(1:2).EQ.'A ') THEN
			MODEL=AMOD
			LMOD=LAMOD
		ELSEIF (NAMEIN(1:2).EQ.'T ') THEN
			MODEL=TMOD
			LMOD=LTMOD
		ELSEIF (NAMEIN(1:2).EQ.'I ') THEN
			MODEL=OMOD
			LMOD=LIMOD
		ELSEIF (NAMEIN(1:3).EQ.'STD') THEN
			MODEL=SMOD
			LMOD=LSMOD
		ELSEIF (NAMEIN(1:3).EQ.'CL ') THEN
			MODEL=CLMOD
			LMOD=LCLMOD
		ELSEIF (NAMEIN(1:3).EQ.'MIX') THEN
			MODEL=MXMOD
			LMOD=LMXMOD
		ELSE
C			-  SPECIAL MODEL.  USE CODE AS SUFFIX.
			IF (LMODPR.EQ.0) THEN
				WRITE (6,*) 'Unrecognized type = ',
     &				 NAMEIN(1:LNBLNK(NAMEIN)),' for ',THCID
				CLOSE (UNIT=1)
				GOTO 990
			ENDIF
			MODEL=MODPRE(1:LMODPR)
			IF (LMODPR.LT.8) THEN
				IF (NAMEIN(1:1).EQ.' ') THEN
					LMOD=LMODPR
				ELSE
					L=LNBLNK(NAMEIN(1:8-LMODPR))
					LMOD=LMODPR+L
					MODEL(LMODPR+1:LMOD)=NAMEIN(1:L)
				ENDIF
			ELSE
				LMOD=LMODPR
			ENDIF
		ENDIF
	ENDIF
  159	CONTINUE
C
C	MAKE SURE MODEL EXE FILE EXISTS
C
	IF (LMODUC.NE.0) THEN
		CMDLIN=MODUIC(1:LMODUC)
		LC=LMODUC+LMOD
		CMDLIN(LMODUC+1:LC)=MODEL(1:LMOD)
	ELSE
		CMDLIN=MODEL(1:LMOD)
		LC=LMOD
	ENDIF
	LC=LC+1
	CMDLIN(LC:LC+3)='.EXE'
	IF (.NOT.INTONL) THEN
		INQUIRE (FILE=CMDLIN,EXIST=ANS)
		IF (.NOT.ANS) THEN
			WRITE (6,*) 'File = ',CMDLIN(1:LC+3),
     &			 ' does not exist.'
			IF (N.EQ.0) GOTO 990
		ENDIF
C
C		WHILE YOU'RE AT IT, MAKE REST OF INT COMMAND LINE
C
		CMDLIN(LC:)=' '//INTID(1:LINTID)//' '//
     &		 EXTFIL(1:LEXTFL)//' REACTCAL'
		LC=LINTID+LC+LEXTFL+10
	ENDIF
C
C
C	DONE PREPARATION.  CONTROL RESUMES AT THIS POINT FOR ALL OPTIONS.
C
  199	CONTINUE
C
C	OPEN scentyp.INP FILE FOR INPUT
C
C	MAKE SURE INP FILE EXISTS
C
	IF (LINPUC.NE.0) THEN
		INLIN=INPUIC(1:LINPUC)
		L=LINPUC+LSCNTP
		INLIN(LINPUC+1:L)=SCNTYP(1:LSCNTP)
	ELSE
		INLIN=SCNTYP(1:LSCNTP)
		L=LSCNTP
	ENDIF
	INLIN(L+1:L+4)='.INP'
	OPEN (UNIT=2,FILE=INLIN,STATUS='OLD',ERR=905)
C
C	OPEN scenid.INT FOR OUTPUT
C
	INLIN=INTID(1:LINTID)//'.INT'
	OPEN (UNIT=3,FILE=INLIN,STATUS='UNKNOWN')
C
C	COPY UNTIL "MODEL=", "SUN", "@MODDOC.IN", "@MODEL.IN", "@TESTHC.IN",
C	"@BASEHC.IN", "@NOX.IN" , @ALOFT.IN, "HV", ".GET", ".LBL1" "TEMPR"
C	RECORD ENCOUNTERED.
C	FOR "MAXO" OPTION, CHECK FOR FIRST .INT AND .SETDEF
C
	PARMIN=.TRUE.
	HVOUT=.TRUE.
	
  200	READ (2,1,END=290) INLIN
	L=LNBLNK(INLIN)
	IF (L.EQ.0) GOTO 200
	IF (INLIN(1:1).EQ.'!') GOTO 200
C
	IF (PARMIN.AND.(INLIN(1:6).EQ.'MODEL='.OR.
     &	 INLIN(1:9).EQ.'@MODEL.IN')) THEN
C		OUTPUT MODEL= RECORD WITH CORRECT MODEL
		WRITE (3,'(''MODEL='',A)') MODEL(1:LMOD)
C
	ELSEIF (PARMIN.AND.(INLIN(1:3).EQ.'SUN'.OR.
     &	 INLIN(1:5).EQ.'P(Z)=')) THEN
		IF (PZFILE(1:1).EQ.' ') THEN
			WRITE (3,1) INLIN(1:L)
		ELSEIF (PZFILE(1:4).EQ.'SUN ') THEN
			WRITE (3,1) 'SUN'
		ELSE
			WRITE (3,1) 'P(Z)='//PZFILE(1:LNBLNK(PZFILE))
		ENDIF
C
	ELSEIF (INLIN(1:3).EQ.'HV '.OR.INLIN(1:3).EQ.'HV='.OR.
     &	 (INLIN(1:2).EQ.'HV'.AND.INLIN(3:3).EQ.TAB)) THEN
		IF (HV.LT.0.0) THEN
			WRITE (3,1) INLIN(1:L)
		ELSE
			WRITE (3,'(''HV'',F12.4)') HV
			HVOUT=.FALSE.
		ENDIF
C
	ELSEIF (INLIN(1:10).EQ.'@MODDOC.IN') THEN
C		WRITE MODEL DOCUMENTATION RECORD
		IF (LMODDC.GT.0) WRITE (3,'(''.LBL6 '',A)') 
     &		 MODDOC(1:LMODDC)
C
	ELSEIF (INLIN(1:5).EQ.'.LBL1') THEN
C		IDENTIFY SCENARIO ID
		WRITE (3,'(''.LBL1 '',A)') SCNID(1:LSCNID)
C
	ELSEIF (INLIN(1:7).EQ.'@NOX.IN') THEN
C		WRITE NOX LEVEL
		IF (NOX) THEN
			IF (.NOT.ADDIN) ADDED=MOLRCT/CORFAC
			WRITE (3,'(''TOT.NOX'',1PE13.3)') NOXLVL+ADDED
		ELSE
			WRITE (3,'(''TOT.NOX'',1PE13.3)') NOXLVL
		ENDIF
C
	ELSEIF (INLIN(1:9).EQ.'@TOTHC.IN') THEN
C		WRITE BASE CASE TOT HC LEVEL
		IF (.NOT.SUBST) WRITE (3,'(''TOT.HC'',1PE14.3)') HCLVL
C
	ELSEIF (INLIN(1:10).EQ.'@BASEHC.IN') THEN
		IF (LBHCID.EQ.0) GOTO 200
C
		WRITE (3,'(''.LBL3 '',A)') BHCID(1:LBHCID)
C
C		GET BASE HC INFO FROM BASEHC FILE
C
		IF (LRXPUC.GT.0) THEN
			INLIN=RXPUIC(1:LRXPUC)
			L=LRXPUC+LBHCID
			INLIN(LRXPUC+1:L)=BHCID(1:LBHCID)
		ELSE
			INLIN=BHCID(1:LBHCID)
			L=LBHCID
		ENDIF
		INLIN(L+1:L+4)='.RXP'
C
		OPEN (UNIT=4,FILE=INLIN,STATUS='OLD',ERR=930)
C
  210		READ (4,1,END=230) INLIN
		WRITE (3,1) INLIN(1:LNBLNK(INLIN))
		GOTO 210
  230		CLOSE (UNIT=4)
C
C
	ELSEIF (INLIN(1:9).EQ.'@ALOFT.IN') THEN
		IF (LAHCID.EQ.0.OR.AHCLVL.EQ.0.0) GOTO 200
C
		IF (AO3LVL.GT.0.0) WRITE (3,'(''A#O3'',F10.5)') AO3LVL
		IF (ANOXLV.GT.0.0) WRITE (3,'(''A#NO2'',F9.5)') ANOXLV
		WRITE (3,'(''! ALOFT HC ID = '',A)') AHCID(1:LAHCID)
		WRITE (3,'(''! ALOFT HC LEVEL = '',F8.4)') AHCLVL
C
C		GET ALOFT HC INFO FROM BASEHC FILE
C
		IF (LRXPUC.GT.0) THEN
			INLIN=RXPUIC(1:LRXPUC)
			L=LRXPUC+LAHCID
			INLIN(LRXPUC+1:L)=AHCID(1:LAHCID)
		ELSE
			INLIN=AHCID(1:LAHCID)
			L=LAHCID
		ENDIF
		INLIN(L+1:L+4)='.LMO'
C
		OPEN (UNIT=4,FILE=INLIN,STATUS='OLD',ERR=932)
C
  240		READ (4,1,END=242) INLIN
		IF (INLIN(1:1).EQ.'!'.OR.INLIN(1:1).EQ.' ') GOTO 240
		CALL PARSE0 (2,INLIN,80)
		CALL PARSE1 (1,NAMEIN,L,8,INLIN)
		IF (NAMEIN(1:1).EQ.' ') GOTO 240
		CALL PARSER (2,X,ANS,INLIN)
		IF (ANS) GOTO 934
		WRITE (3,'(''A#'',A6,1PE12.4)') NAMEIN(1:6),AHCLVL*X
		GOTO 240
  242		CLOSE (UNIT=4)
C
	ELSEIF (INLIN(1:10).EQ.'@TESTHC.IN') THEN
		IF (BASE.OR.NOX.OR.MAXO) GOTO 200
C
		WRITE (3,'(''.LBL4 '',A)') THCID(1:LTHCID)
C
C		IF EXPLICIT, ALL NECESSARY INFO ALREADY AVAILABLE.
C
		IF (EXPTHC) THEN
			WRITE (3,1) 'R3#'//THCID(1:5)//' 1.0'
			CALL EXPLSP (THCID,I,FACRCT,EXPKOH,LEXPK,4)
			IF (NFRMS.GT.0) THEN
				DO 2521 I=1,NFRMS
				IF (THCID(1:5).EQ.FRMSNM(I)) THEN
					FACRCT=FRMS(I)
					GOTO 261
				ENDIF
 2521				CONTINUE
			ENDIF
			GOTO 261
		ENDIF
C
C		TEST HC PROCESSING.  READ AND COPY INPUT FROM
C		TESTHC DATA FILE (OPEN ON UNIT 1).  MEANWHILE,
C		FIGURE OUT MOLES REACTED UNLESS FRACTION REACTED
C		WAS GIVEN EXPLICITLY.
C
C		INPUT GIVEN IN EXPLICIT PARAMETER FILE.  ASSUMES SINGLE
C		MODEL SPECIES NAMED 'GEN1' WITH PARAMETER PREFIX 'G1'
C		INPUT ENDS AT <EOF> OR WHEN "ENDPARMS" LINE IS ENCOUNTERED.
C
		IF (LTSTFL.NE.0) THEN
			WRITE (3,1) 'R3#GEN1 1.0'
			WRITE (3,1) '.NAME GEN1 '//THCID(1:LTHCID)
			ESTFAC=0.0
			PRODIN=.FALSE.
C
 2510			READ (1,1,END=2519) INLIN
			IF (BADFILE) INLIN=INLIN(2:)
			IF (INLIN(1:8).EQ.'ENDPARMS') GOTO 2519
			IF (INLIN(1:1).EQ.'!'.OR.INLIN(1:1).EQ.' ') GOTO 2510
			IF (INLIN(1:3).EQ.'MW ') THEN
				CALL PARSE0 (2,INLIN,80)
				CALL PARSER (2,TSTMWT,ANS,INLIN)
				IF (ANS.OR.TSTMWT.LE.0.0) GOTO 916
			ELSEIF (INLIN(1:3).EQ.'NC ') THEN
				CALL PARSE0 (2,INLIN,80)
				CALL PARSER (2,TSTNC,ANS,INLIN)
				IF (ANS.OR.TSTNC.LE.0) GOTO 916
			ELSEIF (INLIN(1:7).EQ.'FACRCT ') THEN
				CALL PARSE0 (2,INLIN,80)
				CALL PARSER (2,FACRCT,ANS,INLIN)
				IF (ANS.OR.FACRCT.LT.0) GOTO 916
			ELSEIF (INLIN(1:2).EQ.'K(') THEN
C				CONVERT FROM CM2 MOLEC-1 S-1 TO PPM-1 MIN-1
				CALL PARSE0 (4,INLIN,80)
				CALL PARSER (2,A,ANS,INLIN)
				IF (ANS) GOTO 916
				CALL PARSR2 (3,EA,0.0,ANS,INLIN)
				IF (ANS) GOTO 916
				CALL PARSR2 (4,B,0.0,ANS,INLIN)
				IF (ANS) GOTO 916
				A=A*4.40373E+17/TEMP
				RKOH=A*EXP(-EA/(0.0019872*TEMP))*((TEMP/300.0)**B)
				IF (PRODIN) THEN
					WRITE (3,2511) INLIN(3:6),RKOH,A,EA,B
				ELSE
					WRITE (3,2511) 'G1'//INLIN(3:4),RKOH,A,EA,B
				ENDIF
 2511				FORMAT ('K(',A4,')',1P2E12.3,0PF7.3,F5.2)
				IF (INLIN(3:4).EQ.'OH'.AND.FACRCT.EQ.0.0) THEN
					ESTFAC=GETFR(RKOH)
				ENDIF
			ELSEIF (INLIN(1:5).EQ.'PROD ') THEN
				PRODIN=.TRUE.
			ELSEIF (PRODIN) THEN
				WRITE (3,1) INLIN(1:LNBLNK(INLIN))
			ELSE
				WRITE (3,1) 'G1'//INLIN(1:LNBLNK(INLIN))
			ENDIF
			GOTO 2510
 2519			IF (FACRCT.EQ.0.0) THEN
				IF (ESTFAC.GT.0.0) THEN
					FACRCT=ESTFAC
				ELSE
					WRITE (6,*) 'WARNING:  Fraction reacted could',
     &					 ' not computed.  Assumed to be 1.0 (fast).'
					FACRCT=1.0
				ENDIF
			ENDIF
			IF (TSTNC.EQ.0.0) THEN
				WRITE (6,*) 'WARNING:  Carbon no. not given.  ',
     &				 'Assumed to be 1.'
				TSTNC=1.0
			ENDIF
			GOTO 260
		ENDIF
C
C		INPUT GIVEN IN TESTHC FILE
C
		FACRCT=-FACRCT
		LNAM=' '
		F=0.0
C
  250		READ (1,1,END=260) INLIN
		IF (INLIN(1:2).EQ.'##') GOTO 260
C
		L=LNBLNK(INLIN)
		IF (INLIN(1:1).NE.' ') WRITE (3,1) INLIN(1:L)
C
C		LOOK FOR "R3#" TO INDICATE TEST SPECIES,
C		"K(xxOH)" TO INDICATE KOH
C
		IF (INLIN(1:3).EQ.'R3#') THEN
C
C			BEFORE READING NEXT SPECIES, MAKE SURE KOH FOR LAST
C			ONE PROCESSED OK, AND MIX CONTAING SPECIES WHOSE
C			FRACTION REACTED IS NOT KNOWN.
C
			IF (LNAM(1:1).NE.' ') GOTO 940
C
C			READ NAME AND CONC
C
			CALL PARSE0 (2,INLIN(4:),77)
			CALL PARSE1 (1,LNAM,I,5,INLIN(4:))
			CALL PARSER (2,F,ANS,INLIN(4:))
			IF (ANS) GOTO 915
C
C			NO FURTHER PROCSSING IF FRACTION REACTED WAS 
C			ESTIMATED.
C
			IF (FACRCT.LT.0) GOTO 250
C
C			IF FRACTION REACTED WAS GIVEN IN .PRM FILE, THEN
C			FRCRCT IS POSITIVE.  THEN FR-KOH INPUTS IGNORED.
C			OTHERWISE,
C			SEE IF THIS IS EXPLICIT MODEL SPECIES.  IF SO,
C			PROCESS IT.  (IF EXPLICIT, ANS=T, AND X IS FRACT
C			REACTED.)  IF NOT EXPLICIT, NON-BLANK LNAM
C			INDICATES IT NEEDS TO BE PROCESSED.
C
			IF (NFRMS.GT.0) THEN
				DO 252 I=1,NFRMS
				IF (LNAM.EQ.FRMSNM(I)) THEN
					FACRCT=FACRCT+F*FRMS(I)
					LNAM=' '
					GOTO 250
				ENDIF
  252				CONTINUE
			ENDIF
			CALL EXPLSP (LNAM//'   ',I,X,EXPKOH,LEXPK,4)
			IF (I.EQ.0) THEN
				CALL EXPLSP (THCID,I,X,EXPKOH,LEXPK,4)
				IF (I.LT.0) GOTO 980
			ELSEIF (I.LT.0) THEN
				GOTO 980
			ENDIF
			IF (I.EQ.1) THEN
				FACRCT=FACRCT+F*X
				LNAM=' '
			ENDIF
  264			CONTINUE
C
		ELSEIF (INLIN(1:2).EQ.'K('.AND.INLIN(5:7).EQ.'OH)'.
     &		 AND.INLIN(3:3).NE.'p') THEN
C
C			KOH INPUT.  LNAM MUST BE NOLNBLNK TO INDICATE IT WAS
C			NOT PROCESSED.  USE THIS KOH TO PROCESS IT.
C
			IF (FACRCT.LT.0) GOTO 250
			IF (LNAM(1:1).EQ.' ') GOTO 950
			CALL PARSE0 (2,INLIN,80)
			CALL PARSER (2,RKOH,ANS,INLIN)
			IF (ANS) GOTO 952
			FACRCT=FACRCT+F*GETFR(RKOH)
			F=0.0
			LNAM=' '
C
		ENDIF
C
		GOTO 250
C
C		DETERMINE AMOUNT ADDED.  DEPENDS ON OPTION.
C		DEFAULT -- SO THAT CARBONS REACTING = BASE VOC * MOLRCT
C		PERCNT -- BASED ON PERCENTAGE OF BASE VOC
C		ADDIN -- GIVEN EXPLICITLY
C		USENC -- BASE ESTIMATED AMOUNT ADDED ON MOLES CARBON RATHER THAN MOLES
C
  260		CLOSE (UNIT=1)
  261		IF (FACRCT.EQ.0.0) THEN
			WRITE (6,*) THCID(1:LTHCID),
     &			 ' estimated not to react.'
			GOTO 980
		ENDIF
		IF (PERCNT) THEN
			ADDED=HCLVL*ADDED/100.0
		ELSEIF (.NOT.ADDIN) THEN
C			ADDED 1/4/01 TO CONTROL MOLE VS MOLE CARBON ADDITION.
			IF (USENC) THEN
				ADDED=MOLRCT/(ABS(FACRCT)*CORFAC*TSTNC)
			ELSE
				ADDED=MOLRCT/(ABS(FACRCT)*CORFAC)
			ENDIF
		ENDIF
C
C		SUBSTITUTION OPTION:  BASE VOC REDUCED BY AMOUNT ADDED.
C
C		OUTPUT AMOUNT ADDED AND (IF APPLICABLE) BASE VOC IF
C		DIFFERENT FROM BASE CASE.
C
		IF (SUBST) THEN
			WRITE (3,'(''TOT.HC'',1PE14.3)') HCLVL-ADDED
			ADDED=ADDED*SUBFAC
			WRITE (3,1) '.LBL3 SUBST.'
			WRITE (3,'(''TOT.THC '',1PE14.3)') ADDED
		ELSE
			WRITE (3,'(''.LBL5 '',1PE8.1)') ADDED
			WRITE (INLIN,'(''TOT.THC '',1PE8.1)') ADDED
			WRITE (3,1) INLIN(1:16)
C		      -	SET MOLRCT TO VALUE READ BY INT.
			READ (INLIN,'(8X,E8.1)') ADDED
		ENDIF
C
	ELSEIF (PARMIN.AND.INLIN(1:L).EQ.'.') THEN
		PARMIN=.FALSE.
		WRITE (3,'(''EPS'',1PE10.2/''.'')') EPS
	ELSEIF (PARMIN.AND.INLIN(1:3).EQ.'EPS') THEN
		GOTO 200
C
	ELSEIF (INLIN(1:5).EQ.'TEMPR'.OR.INLIN(1:5).EQ.'.TEMP') THEN
		CALL PARSE0 (2,INLIN,80)
		CALL PARSER (2,F,ANS,INLIN)
		IF ((.NOT.ANS).AND.F.GT.0.0) TEMP=F
C
	ELSEIF (INLIN(1:4).EQ.'.INT'.OR.INLIN(1:7).EQ.'.SETDEF') THEN
C
C		INSERT ANY MISSING DEFAULT DATA NEEDED BEFORE FIRST .INT
C		OR .SETDEF
C		INSERT @REACTCAL.IN BEFORE FIRST .INT OR .SETDEF
C
		IF (HV.GE.0.0.AND.HVOUT) THEN
			WRITE (3,'(''HV'',F14.4)') HV
			HVOUT=.FALSE.
		ENDIF
		IF (INSO) THEN
			WRITE (3,1) '@REACTCAL.IN'
			INSO=.FALSE.
		ENDIF
C
		IF (INTIN) THEN
			OPEN (UNIT=8,FILE='TMP.IN',STATUS='OLD')
   18			READ (8,1,END=17) INLIN2
			WRITE (3,1) INLIN2(1:LNBLNK(INLIN2))
			GOTO 18
   17			CLOSE (UNIT=8,STATUS='DELETE')
			INTIN=.FALSE.
		ENDIF
		WRITE (3,1) INLIN(1:L)
C
	ELSE
C
C		OTHER INPUT.  JUST COPY LINE
C
		WRITE (3,1) INLIN(1:L)
C
	ENDIF
	GOTO 200
C
C	END CREATING .INT FILE.
C
  290	CLOSE (UNIT=2)
	CLOSE (UNIT=3)
	IF (INTONL.OR.MAXO) THEN
		WRITE (6,*) 'File = ',INTID(1:LINTID),'.INT created.'
		IF (MAXO) THEN
			OPEN (UNIT=2,FILE='REACTCAL.IN',STATUS='UNKNOWN')
			WRITE (2,291) HCLVL,NOXLVL,O3MAX,CORFAC
  291			FORMAT ('!HC,NOX,O3M,CORR= ',1P4E14.7)
			CLOSE (UNIT=2)
		ENDIF
		CALL EXIT (0)
	ENDIF
C
C	RUN INTEGRATION (UNLESS CALC NO. GIVEN EXPLICITLY)
C
C
C	RUN INT
C
C	DELETE "STATUS.TMP" FILE IF IT EXISTS.  IT IS USED TO CHECK
C	FOR SUCESSFUL CALCULATION.
C
	OPEN (UNIT=1,FILE='STATUS.TMP',STATUS='UNKNOWN')
	CLOSE (UNIT=1,STATUS='DELETE')
C
CD	WRITE (6,*) CMDLIN(1:LC)
	CALL SYSTEM (CMDLIN(1:LC))
C
C	CHECK STATUS.TMP FOR SUCCESS OR FAILURE.
C
	OPEN (UNIT=1,FILE='STATUS.TMP',STATUS='OLD',ERR=961)
	READ (1,1,END=960) INLIN
	IF (INLIN(1:6).NE.'INT OK') GOTO 962
C
C	READ MAX CONC'S OF O3 AND OTHERS FROM STATUS.TMP
C	1 = MAX, 2 = MAX TIME, 3 = FINAL, 4 = SUM
C
	DO 2911 I=1,NMXC
	MXCONC(1,I)=0.0
	MXCONC(2,I)=0.0
	MXCONC(3,I)=0.0
 2911	MXCONC(4,I)=0.0
C
	READ (INLIN,'(6X,I3)',ERR=962) N
	IF (N.EQ.0) GOTO 963
	DO 2912 J=1,N
	READ (1,1,END=964) INLIN
	IF (INLIN(1:3).EQ.'MAX') THEN
		READ (INLIN,2914,ERR=965) NAMEIN,F,FT,FL,FS
 2914		FORMAT (4X,A5,11X,E16.7,F10.2,2E16.7)
		DO 2913 I=1,NMXC
		IF (NAMEIN(1:5).EQ.MXCNAM(I)) THEN
			MXCONC(1,I)=F
			MXCONC(2,I)=FT
			MXCONC(3,I)=FL
			MXCONC(4,I)=FS
			GOTO 2912
		ENDIF
 2913		CONTINUE
	ENDIF
 2912	CONTINUE
C
	IF (MXCONC(1,1).EQ.0.0) THEN
		WRITE (6,*) 'Max O3 zero or undefined.'
		GOTO 960
	ENDIF
	CLOSE (UNIT=1,STATUS='DELETE')
CD	CLOSE (UNIT=1)
C
C
C	IF BASE CASE, CALL BASRCT.  IF TESTHC, CALL INCRCT
C	IN EITHER CASE, OPEN CALC FILE FOR INPUT AND scenid.CLC
C	TO APPEND OUTPUT.  ALSO, IF BASE OPEN scenid.PRM TO APPEND
C	PARMS, OR IF TESTHC, OPEN IT TO READ.
C
C	OPEN CALC .CDA FILE.
C
  300	CONTINUE
	INLIN=CALUIC(1:LCALUC)//EXTFIL(1:LEXTFL)//'\'//
     &	 INTID(1:LINTID)//'.CDA'
	LF=LCALUC+LEXTFL+LINTID+5
	OPEN (UNIT=1,FILE=INLIN,STATUS='OLD',ERR=308,ACTION='READ')
	GOTO 309
  308	WRITE (6,*) 'Calc file = '//INLIN(1:LF)//' not found.'
	CALL EXIT (2)
  309	CONTINUE
C
C	SPECIAL PROCESSING FOR EXPLICIT AMOUNT ADDED OR SUBSTITUTED
C
	IF (SUBST.OR.ADDIN) THEN
C
C		IDENTIFYING INFO IN BUFFER
C
		IF (PERCNT) ADDED=100.*ADDED/HCLVL
		INLIN=' '
		IF (SUBST) THEN
			WRITE (INLIN,302) SCNID,THCID,'SUB',ADDED/SUBFAC,
     &			 SUBFAC
		ELSE
			WRITE (INLIN,302) SCNID,THCID,'ADD',ADDED
		ENDIF
  302		FORMAT (A8,',',A8,',',A3,',',F6.2,' ,',F6.3)
		IF (PERCNT) INLIN(29:29)='%'
C
C		READ THE CALC FILE TO GET THE RESULTS, AND ADD
C		TO LOG FILE
C
		CALL LOGCHG (.FALSE.,1,INLIN,12,'SUBSTDAT.CSV')
		CALL EXIT (0)
C
	ENDIF
C
C	NORMAL REACTIVITY PROCESSING
C
C
C	OPEN scenid.CLC AND scenid.CLD FILE FOR APPEND.
C
	INLIN=CLCUIC
	INLIN(LCLCUC+1:LCLCUC+LSCNID)=SCNID(1:LSCNID)
	INLIN(LCLCUC+LSCNID+1:LCLCUC+LSCNID+4)='.CLC'
	OPEN (UNIT=2,FILE=INLIN,STATUS='UNKNOWN',ACCESS='APPEND')
C
	INLIN(LCLCUC+LSCNID+1:LCLCUC+LSCNID+4)='.CLD'
	OPEN (UNIT=4,FILE=INLIN,STATUS='UNKNOWN',ACCESS='APPEND')
C
C	scenid.BAS OPENED NEW IF BASE, OLD IF TEST.
C
C
	IF (BASE) THEN
		IF (BHCID(1:1).EQ.' ') THEN
			WRITE (2,310) SCNID(1:LSCNID),SCNTYP(1:LSCNTP)
  310			FORMAT (/' ScenID = ',A,',  ScenTyp = ',A,
     &                   ',  BaseHC = (none)'/)
		ELSE
			WRITE (2,311) SCNID(1:LSCNID),SCNTYP(1:LSCNTP),
     &			 BHCID(1:LBHCID)
  311			FORMAT (/'  ScenID = ',A,',  ScenTyp = ',A,
     &                   ',  BaseHC = ',A/)
		ENDIF
C
C		INITIALIZE .BAS FILE
C
		INLIN(LCLCUC+LSCNID+2:LCLCUC+LSCNID+4)='BAS'
		OPEN (UNIT=3,FILE=INLIN,STATUS='UNKNOWN')
		CLOSE (UNIT=3,STATUS='DELETE')
		OPEN (UNIT=3,FILE=INLIN,STATUS='NEW')
		CALL SOPOUT (3,SCNID,.FALSE.)
C
		CALL BASRCT (1,2,4,3,I,O3KODE,NMXC,MXCNAM,MXCONC)
		IF (I.LT.0) THEN
			WRITE (6,*) 'BASRCT failed'
			CALL EXIT (2)
		ENDIF
		WRITE (6,3111) INLIN(1:LNBLNK(INLIN))
 3111		FORMAT (' Base calculation results given in fil',
     &           'e = ',A)
C
	ELSE
C
		IF (NOX) FACRCT=1.0
		CALL INCRCT (THCID,1,2,4,I,ADDED,FACRCT,O3KODE,
     &		 NMXC,MXCONC,BASDAT,CORFAC,TSTNC,TSTMWT,TSTID)
		IF (I.LT.0) THEN
			WRITE (6,*) 'INCRCT failed'
			CALL EXIT (2)
		ENDIF	
		WRITE (6,3112) SCNID(1:LSCNID),THCID(1:LTHCID)
 3112		FORMAT (' Reactivity calculation done for ',A,1X,A)
	ENDIF
C
C	IF SUCCESSFUL DELETE .INT FILE
C
	INLIN=INTID(1:LINTID)//'.INT'
	OPEN (UNIT=1,FILE=INLIN,STATUS='OLD')
	CLOSE (UNIT=1,STATUS='DELETE')
C
C	DONE
C
	CALL EXIT (0)
C
C	ERRORS
C
  900	WRITE (6,*) 'File = ',INLIN(1:LF),' does not exist.'
	GOTO 990
  901	WRITE (6,*) 'Error decoding amount added/substituted on ',
     &	 'command line.'
	GOTO 990
  902	WRITE (6,*) 'File = ',SCNPRM(1:LSPMFL),' does not exist.'
	GOTO 990
  905	WRITE (6,*) 'FILE = ',INLIN(1:L+4),' does not exist.'
	GOTO 990
  910	WRITE (6,*) 'TESTHC file = ',THCFIL(1:LTHCFL),' does not exist.'
	GOTO 990
  912	WRITE (6,*) 'General HC parameter file = ',TSTFIL(1:LTSTFL),
     &	 ' does not exist.'
	GOTO 990
  915	WRITE (6,*) 'Error reading TESTHC file = ',THCFIL(1:LTHCFL)
	GOTO 955
  916	WRITE (6,*) 'Error reading general HC parameter file = ',
     &	 TSTFIL(1:LTHCFL)
	GOTO 955
  920	WRITE (6,*) 'TESTHC = ',THCID(1:LTHCID),' not found in file = ',
     &	 THCFIL(1:LTHCFL)
	GOTO 990
  922	WRITE (6,*) 'No data found in general HC parameter file. = ',
     &	 TSTFIL(1:LTSTFL)
	GOTO 990
  930	WRITE (6,*) 'BASEHC file = ',INLIN(1:L+4),' does not exist.'
	GOTO 980
  932	WRITE (6,*) 'ALOFTHC file = ',INLIN(1:L+4),' does not exist.'
	GOTO 980
  934	WRITE (6,*) 'Bad data in ALOFTHC file.  Input = "',
     &	 INLIN(1:LNBLNK(INLIN)),'".'
	CLOSE (UNIT=4)
	GOTO 980
  940	WRITE (6,*) 'No KOH in EXPLICIT-KOH file for ',LNAM
	GOTO 980
  942	WRITE (6,*) 'File = ',MXCLIS(2:LNBLNK(MXCLIS)),' does not exist.'
	GOTO 990
  950	WRITE (6,*) 'No species associated with KOH input line:'
	GOTO 955
  952	WRITE (6,*) 'Can''t decode KOH input line:'
C
  955	WRITE (6,*) 'Bad line = "',INLIN(1:LNBLNK(INLIN)),'"'
	GOTO 980
  960	CLOSE (UNIT=1)
	GOTO 961
  962	WRITE (6,*) 'INT error message = ',INLIN(1:LNBLNK(INLIN))
	CLOSE (UNIT=1)
	GOTO 961
  963	WRITE (6,*) 'INT did not leave max conc. of O3 or other',
     &	 ' species.'
	GOTO 961
  964	WRITE (6,*) 'Unexpected <eof> when reading STATUS.TMP from INT.'
	GOTO 961
  965	WRITE (6,*) 'Error reading data from STATUS.TMP from INT.'
	WRITE (6,*) 'Bad line = ',INLIN(1:LNBLNK(INLIN))
  961	WRITE (6,*) 'INT failed.'
	GOTO 990
C
  980	CLOSE (UNIT=3)
  990	WRITE (6,*) 'Failed'
	CALL EXIT (2)
	END
